2.1 amixer ¶
Provide an emacs front-end to amixer,
the sound mixer in ALSA that is used to configure the audio device.
Note that amixer also works on pipewire-based systems.
The main entry point is command amixer bound
to C-e). When called for the first time, this command
builds up a database of available controls on the default audio
device. These control names are then available for completion in
the minibuffer. Pick a desired control, e.g., "master playback
volume", and this displays a prompt with the current value. Enter
the new value and press <RETURN>. To reset all controls to their
default values, Press C-j.
2.1.1 Amixer Commands ¶
2.1.1.1 amixer ¶
- Command: amixer (&optional refresh) ¶
- C-e ( ¶
2.1.1.2 amixer-query ¶
- Command: amixer-query (&optional refresh) ¶
-
2.1.1.3 amixer-store ¶
- Command: amixer-store ¶
-
2.1.1.4 amixer-volume-adjust ¶
- Command: amixer-volume-adjust ¶
- C-e 4 ¶
- C-e 3 ¶
2.1.1.5 amixer-volume-down ¶
- Command: amixer-volume-down (&optional prompt) ¶
- <XF86AudioLowerVolume> ¶
- C-<f1> ¶
2.1.1.6 amixer-volume-up ¶
- Command: amixer-volume-up (&optional prompt) ¶
- <XF86AudioRaiseVolume> ¶
- C-<f2> ¶
2.1.2 amixer Options ¶
- Variable: User Option amixer-volume-step ¶
Step-size for volume change.
Default Value:
1