2.4 emacsvox ¶
Emacsvox extends Emacs to be a fully functional audio desktop.
This is the main emacsvox module.
It actually does very little:
- It sets up Emacs to load package-specific
Emacsvox modules as and when a package is loaded.
- It implements function emacsvox which loads the rest of the
system.
- It provides affordances for setting up consistent behavior in
programming modes.
2.4.1 emacsvox Options ¶
- Variable: User Option emacsvox-pip-enable ¶
Load pip if Piper-TTS is available.
Default Value:
nil