Structure emacsvox-amark holds a bookmark into an mp3 file path: filename containing marked name: Bookmark tag Position: time offset from start
This library will be used from emacsvox-m-player to set and jump
to bookmarks. Amarks are stored in a .amarks.am file in the working
directory. It also provides a simple AMark Browser to use from a
directory containing mp3 files where Amarks have been created –
see emacsvox-amarks-browse.
emacsvox-amarks-bookshelf brings up a AmarksBookshelf
that can be used to browse available Amark files.
Add an AMark to the buffer local list of AMarks. AMarks are bookmarks in audio content. If there is an existing amark of the given name, it is updated with path and position. (fn PATH NAME POSITION)
Open a locate buffer with all .amarks.am files. Optional interactive prefix arg prompts for a pattern that is used to filter the amarks files to show. Use M-x emacsvox-dired-open-this-file to open the AMark Browser on current file. (fn &optional PATTERN)
Open .amark.el on current line in AMark Browser
Return matching AMark if found in buffer-local AMark list. (fn NAME)
Play amark list as a playlist. Maps command M-x emacsvox-m-player across elements of the amarks list. Pressing ‘y’ as the current item is playing skips to the next item; this ‘y/n’ prompt is produced by M-x emacsvox-m-player as is usual when that command is called while media is already playing. Here, attempting to play the next item while the current item is playing produces the prompt.
A light-weight mode for the ‘*Emacsvox Amark Browser*’. 1. Provides buttons for opening and removing AMarks. 2. Enables org integration via command ‘org-store-link’ bound to M-x org-store-link. 3. Stored links can be inserted into org files in the same directory via command ‘org-insert-link’ bound to M-x org-insert-link. In addition to any hooks its parent mode ‘special-mode’ might have run, this mode runs the hook ‘emacsvox-amark-mode-hook’, as the final or penultimate step during initialization.