2.13 emacsvox-arc

Auditory interface to archive mode This lets Emacs manipulate package files such as .zip and .jar files.

2.13.1 Emacsvox-Arc Commands

2.13.1.1 emacsvox-arc-speak-file-modification-time

Command: emacsvox-arc-speak-file-modification-time
Speak modification time of the file on current line

2.13.1.2 emacsvox-arc-speak-file-name

Command: emacsvox-arc-speak-file-name
Speak the name of the file on current line

2.13.1.3 emacsvox-arc-speak-file-permissions

Command: emacsvox-arc-speak-file-permissions
Speak permissions of file current entry

2.13.1.4 emacsvox-arc-speak-file-size

Command: emacsvox-arc-speak-file-size
Speak the size of the file on current line