2.14 emacsvox-auctex

Speech-enables the AucTeX package. AucTeX, now available from ELPA, has been my authoring environment of choice for writing LaTeX since 1991.

2.14.1 Emacsvox-Auctex Commands

2.14.1.1 emacsvox-auctex-comma-at-end-of-word

Command: emacsvox-auctex-comma-at-end-of-word
Move to the end of current word and add a comma.

2.14.1.2 emacsvox-auctex-end-of-word

Command: emacsvox-auctex-end-of-word (arg)
move to end of word

(fn ARG)

2.14.1.3 emacsvox-auctex-lacheck-buffer-file

Command: emacsvox-auctex-lacheck-buffer-file
Run Lacheck on current buffer.

2.14.1.4 emacsvox-auctex-tex-tie-current-word

Command: emacsvox-auctex-tex-tie-current-word (n)
Tie the next n  words.

(fn N)