2.20 emacsvox-aural-doctor

Diagnose the running aural installation and configuration without starting a speech server or changing presentation state. Safe, deterministic repairs are explicit commands from the spoken report.

2.20.1 Emacsvox-Aural-Doctor Commands

2.20.1.1 emacsvox-aural-doctor

Command: emacsvox-aural-doctor
Open the spoken Aural Doctor and announce its overall result.

2.20.1.2 emacsvox-aural-doctor-help

Command: emacsvox-aural-doctor-help
Display and speak Aural Doctor help.

2.20.1.3 emacsvox-aural-doctor-mode

Command: emacsvox-aural-doctor-mode
Spoken diagnostics for aural presentation.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-doctor-mode-hook’, as the final or penultimate
step during initialization.

Key             Binding
——————————————————————————-
?		emacsvox-aural-doctor-help
h		emacsvox-aural
r		emacsvox-aural-doctor-repair-current

2.20.1.4 emacsvox-aural-doctor-next

Command: emacsvox-aural-doctor-next
Move to and speak the next diagnostic finding.

2.20.1.5 emacsvox-aural-doctor-next-column

Command: emacsvox-aural-doctor-next-column
Move right and speak the next diagnostic column.

2.20.1.6 emacsvox-aural-doctor-previous

Command: emacsvox-aural-doctor-previous
Move to and speak the previous diagnostic finding.

2.20.1.7 emacsvox-aural-doctor-previous-column

Command: emacsvox-aural-doctor-previous-column
Move left and speak the previous diagnostic column.

2.20.1.8 emacsvox-aural-doctor-refresh

Command: emacsvox-aural-doctor-refresh (&optional id)
Rerun diagnostics, preserving row ID and the current column.

(fn &optional ID)

2.20.1.9 emacsvox-aural-doctor-refresh-sound-packs

Command: emacsvox-aural-doctor-refresh-sound-packs
Refresh dynamically discovered and registered sound packs.

2.20.1.10 emacsvox-aural-doctor-reload-personal-data

Command: emacsvox-aural-doctor-reload-personal-data
Reload the validated personal aural data file.

2.20.1.11 emacsvox-aural-doctor-repair-current

Command: emacsvox-aural-doctor-repair-current
Run the deterministic repair offered by the finding at point.

2.20.1.12 emacsvox-aural-doctor-restore-bindings

Command: emacsvox-aural-doctor-restore-bindings
Restore the documented aural home and point-explanation bindings.

2.20.1.13 emacsvox-aural-doctor-speak-current

Command: emacsvox-aural-doctor-speak-current
Speak the complete diagnostic finding at point.

2.20.1.14 emacsvox-aural-doctor-speak-current-cell

Command: emacsvox-aural-doctor-speak-current-cell
Speak the current diagnostic column title and value.