2.25 emacsvox-aural-home

Status and routing home for aural presentation discovery, management, diagnosis, and contextual remapping.

2.25.1 Emacsvox-Aural-Home Commands

2.25.1.1 emacsvox-aural

Command: emacsvox-aural (&optional source-buffer)
C-e H
Open the spoken aural home using SOURCE-BUFFER for contextual operations.

(fn &optional SOURCE-BUFFER)

2.25.1.2 emacsvox-aural-home-activate

Command: emacsvox-aural-home-activate
Perform the primary operation for the aural home row at point.

2.25.1.3 emacsvox-aural-home-explain

Command: emacsvox-aural-home-explain
Explain presentation at point in the remembered source buffer.

2.25.1.4 emacsvox-aural-home-help

Command: emacsvox-aural-home-help
Display and speak aural home commands and discovery guidance.

2.25.1.5 emacsvox-aural-home-mode

Command: emacsvox-aural-home-mode
Spoken home mode for aural presentation discovery and interaction.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-home-mode-hook’, as the final or penultimate step
during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-home-activate
?		emacsvox-aural-home-help
D		emacsvox-aural-doctor
H		emacsvox-aural-home-recent-feedback
O		emacsvox-aural-home-overrides
P		emacsvox-aural-home-profiles
R		emacsvox-aural-home-remap-earcon
V		emacsvox-aural-home-voice-palettes
W		emacsvox-aural-home-voice-workbench
r		emacsvox-aural-home-remap-voice
x		emacsvox-aural-home-explain

2.25.1.6 emacsvox-aural-home-next

Command: emacsvox-aural-home-next
Move to and speak the next aural home row.

2.25.1.7 emacsvox-aural-home-next-column

Command: emacsvox-aural-home-next-column
Move right and speak the next aural home column.

2.25.1.8 emacsvox-aural-home-overrides

Command: emacsvox-aural-home-overrides
Open unified presentation overrides from Aural Home.

2.25.1.9 emacsvox-aural-home-previous

Command: emacsvox-aural-home-previous
Move to and speak the previous aural home row.

2.25.1.10 emacsvox-aural-home-previous-column

Command: emacsvox-aural-home-previous-column
Move left and speak the previous aural home column.

2.25.1.11 emacsvox-aural-home-profiles

Command: emacsvox-aural-home-profiles
Open the complete presentation-profile manager.

2.25.1.12 emacsvox-aural-home-recent-feedback

Command: emacsvox-aural-home-recent-feedback
Open bounded retained presentations from Aural Home.

2.25.1.13 emacsvox-aural-home-refresh

Command: emacsvox-aural-home-refresh (&optional id)
Refresh aural home status, preserving row ID and the current column.

(fn &optional ID)

2.25.1.14 emacsvox-aural-home-remap-earcon

Command: emacsvox-aural-home-remap-earcon
Prepare an earcon override for the remembered source item.

2.25.1.15 emacsvox-aural-home-remap-voice

Command: emacsvox-aural-home-remap-voice
Prepare a voice override for the remembered source item.

2.25.1.16 emacsvox-aural-home-speak-current

Command: emacsvox-aural-home-speak-current
Speak the complete aural home row at point.

2.25.1.17 emacsvox-aural-home-speak-current-cell

Command: emacsvox-aural-home-speak-current-cell
Speak the current aural home column title and value.

2.25.1.18 emacsvox-aural-home-voice-palettes

Command: emacsvox-aural-home-voice-palettes
Open the accessible voice-palette manager.

2.25.1.19 emacsvox-aural-home-voice-workbench

Command: emacsvox-aural-home-voice-workbench
Open cross-synth voice routing and style management.