Present personal, session, and source-buffer rules as one accessible view. This manager does not introduce another presentation layer: it explains and mutates the existing strongest three layers in the aural cascade.
Open the unified Presentation Overrides manager for optional SOURCE. (fn &optional SOURCE)
Clear every override-manager filter.
Remove the selected override and restore weaker presentation.
Display and speak complete details for the override at point.
Open the selected override in its scoped advanced editor.
Filter overrides by scope, module, and semantic role.
Display and speak Presentation Overrides help.
Spoken manager for personal, session, and buffer presentation overrides. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-overrides-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-overrides-edit ? emacsvox-aural-overrides-help P emacsvox-aural-overrides-preview a emacsvox-aural-overrides-clear-filter d emacsvox-aural-overrides-delete e emacsvox-aural-overrides-edit f emacsvox-aural-overrides-filter h emacsvox-aural t emacsvox-aural-overrides-toggle x emacsvox-aural-overrides-describe
Move to and speak the next presentation override.
Move right and speak the next override column.
Preview the selected override in the complete current cascade.
Move to and speak the previous presentation override.
Move left and speak the previous override column.
Refresh overrides, preserving optional row KEY and current column. (fn &optional KEY)
Speak the complete presentation override at point.