2.43 emacsvox-aural-semantics

Semantic selection, representative facts, reference discovery, and the accessible browser for the registered aural vocabulary.

2.43.1 Emacsvox-Aural-Semantics Commands

2.43.1.1 emacsvox-aural-describe-semantic

Command: emacsvox-aural-describe-semantic (&optional semantic)
Describe registered SEMANTIC and presentation data that uses it.

(fn &optional SEMANTIC)

2.43.1.2 emacsvox-aural-list-semantics

Command: emacsvox-aural-list-semantics
Open the accessible list of registered semantic vocabulary.

2.43.1.3 emacsvox-aural-semantics-help

Command: emacsvox-aural-semantics-help
Display and speak semantic-list help.

2.43.1.4 emacsvox-aural-semantics-mode

Command: emacsvox-aural-semantics-mode
Major mode for browsing registered aural semantics.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-semantics-mode-hook’, as the final or penultimate
step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-describe-aural-semantic
?		emacsvox-aural-semantics-help
h		emacsvox-aural

2.43.1.5 emacsvox-aural-semantics-next

Command: emacsvox-aural-semantics-next
Move to and speak the next semantic.

2.43.1.6 emacsvox-aural-semantics-next-column

Command: emacsvox-aural-semantics-next-column
Move right and speak the next semantic column title and value.

2.43.1.7 emacsvox-aural-semantics-previous

Command: emacsvox-aural-semantics-previous
Move to and speak the previous semantic.

2.43.1.8 emacsvox-aural-semantics-previous-column

Command: emacsvox-aural-semantics-previous-column
Move left and speak the previous semantic column title and value.

2.43.1.9 emacsvox-aural-semantics-refresh

Command: emacsvox-aural-semantics-refresh (&optional semantic)
Refresh the semantic list, preserving SEMANTIC and the current column.

(fn &optional SEMANTIC)

2.43.1.10 emacsvox-aural-semantics-speak-current

Command: emacsvox-aural-semantics-speak-current
Speak a concise description of the semantic at point.

2.43.1.11 emacsvox-aural-semantics-speak-current-cell

Command: emacsvox-aural-semantics-speak-current-cell
Speak the current semantic column title and value.

2.43.1.12 emacsvox-describe-aural-semantic

Command: emacsvox-describe-aural-semantic (&optional semantic)
Describe registered SEMANTIC and presentation data that uses it.

(fn &optional SEMANTIC)

2.43.1.13 emacsvox-list-aural-semantics

Command: emacsvox-list-aural-semantics
Open the accessible list of registered semantic vocabulary.