2.44 emacsvox-aural-sound-packs

Accessible sound-pack and cue browsers. Users can inspect native, inherited, fallback, and missing assets; audition concrete cues; activate packs; validate coverage; open directories; and edit safe discovered-pack manifests without editing raw Lisp.

2.44.1 Emacsvox-Aural-Sound-Packs Commands

2.44.1.1 emacsvox-aural-list-sound-pack-cues

Command: emacsvox-aural-list-sound-pack-cues (&optional pack)
Open the spoken cue browser for PACK or the sound pack at point.

(fn &optional PACK)

2.44.1.2 emacsvox-aural-list-sound-packs

Command: emacsvox-aural-list-sound-packs (&optional pack)
Open the spoken sound-pack manager, selecting PACK when supplied.

(fn &optional PACK)

2.44.1.3 emacsvox-aural-sound-pack-cues-audition

Command: emacsvox-aural-sound-pack-cues-audition
Audition the concrete cue at point.

2.44.1.4 emacsvox-aural-sound-pack-cues-help

Command: emacsvox-aural-sound-pack-cues-help
Display and speak sound-pack cue-browser help.

2.44.1.5 emacsvox-aural-sound-pack-cues-mode

Command: emacsvox-aural-sound-pack-cues-mode
Spoken browser for sound-pack cue intent and concrete provenance.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-sound-pack-cues-mode-hook’, as the final or
penultimate step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-sound-pack-cues-audition
?		emacsvox-aural-sound-pack-cues-help
P		emacsvox-aural-sound-pack-cues-audition
h		emacsvox-aural
o		emacsvox-aural-sound-packs-open-directory
s		emacsvox-aural-list-sound-packs
v		emacsvox-aural-sound-pack-cues-show-validation

2.44.1.6 emacsvox-aural-sound-pack-cues-next

Command: emacsvox-aural-sound-pack-cues-next
Move to and speak the next cue.

2.44.1.7 emacsvox-aural-sound-pack-cues-next-column

Command: emacsvox-aural-sound-pack-cues-next-column
Move right and speak the next cue column.

2.44.1.8 emacsvox-aural-sound-pack-cues-previous

Command: emacsvox-aural-sound-pack-cues-previous
Move to and speak the previous cue.

2.44.1.9 emacsvox-aural-sound-pack-cues-previous-column

Command: emacsvox-aural-sound-pack-cues-previous-column
Move left and speak the previous cue column.

2.44.1.10 emacsvox-aural-sound-pack-cues-refresh

Command: emacsvox-aural-sound-pack-cues-refresh (&optional cue)
Refresh the cue browser, preserving CUE and the current column.

(fn &optional CUE)

2.44.1.11 emacsvox-aural-sound-pack-cues-show-validation

Command: emacsvox-aural-sound-pack-cues-show-validation
Display and speak validation for the cue browser’s sound pack.

2.44.1.12 emacsvox-aural-sound-pack-cues-speak-current

Command: emacsvox-aural-sound-pack-cues-speak-current
Speak the cue, provenance, and intent at point.

2.44.1.13 emacsvox-aural-sound-pack-cues-speak-current-cell

Command: emacsvox-aural-sound-pack-cues-speak-current-cell
Speak the current cue-browser column title and value.

2.44.1.14 emacsvox-aural-sound-packs-activate

Command: emacsvox-aural-sound-packs-activate
Activate the sound pack at point.

2.44.1.15 emacsvox-aural-sound-packs-audition

Command: emacsvox-aural-sound-packs-audition
Audition a representative cue from the sound pack at point.

2.44.1.16 emacsvox-aural-sound-packs-edit-manifest

Command: emacsvox-aural-sound-packs-edit-manifest
Guidedly edit safe manifest metadata for the discovered pack at point.

2.44.1.17 emacsvox-aural-sound-packs-help

Command: emacsvox-aural-sound-packs-help
Display and speak sound-pack manager help.

2.44.1.18 emacsvox-aural-sound-packs-mode

Command: emacsvox-aural-sound-packs-mode
Spoken manager for registered and dynamically discovered sound packs.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-sound-packs-mode-hook’, as the final or
penultimate step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-list-sound-pack-cues
?		emacsvox-aural-sound-packs-help
P		emacsvox-aural-sound-packs-audition
a		emacsvox-aural-sound-packs-activate
e		emacsvox-aural-sound-packs-edit-manifest
h		emacsvox-aural
o		emacsvox-aural-sound-packs-open-directory
v		emacsvox-aural-sound-packs-show-validation

2.44.1.19 emacsvox-aural-sound-packs-next

Command: emacsvox-aural-sound-packs-next
Move to and speak the next sound pack.

2.44.1.20 emacsvox-aural-sound-packs-next-column

Command: emacsvox-aural-sound-packs-next-column
Move right and speak the next sound-pack column.

2.44.1.21 emacsvox-aural-sound-packs-open-directory

Command: emacsvox-aural-sound-packs-open-directory
Open the current sound pack’s directory in Dired.

2.44.1.22 emacsvox-aural-sound-packs-previous

Command: emacsvox-aural-sound-packs-previous
Move to and speak the previous sound pack.

2.44.1.23 emacsvox-aural-sound-packs-previous-column

Command: emacsvox-aural-sound-packs-previous-column
Move left and speak the previous sound-pack column.

2.44.1.24 emacsvox-aural-sound-packs-refresh

Command: emacsvox-aural-sound-packs-refresh (&optional pack)
Refresh the sound-pack manager, preserving PACK and the current column.

(fn &optional PACK)

2.44.1.25 emacsvox-aural-sound-packs-show-validation

Command: emacsvox-aural-sound-packs-show-validation (&optional pack-id)
Display and speak validation for PACK-ID or the pack at point.

(fn &optional PACK-ID)

2.44.1.26 emacsvox-aural-sound-packs-speak-current

Command: emacsvox-aural-sound-packs-speak-current
Speak a natural summary of the sound pack at point.

2.44.1.27 emacsvox-aural-sound-packs-speak-current-cell

Command: emacsvox-aural-sound-packs-speak-current-cell
Speak the current sound-pack column title and value.