2.50 emacsvox-aural-ui

Common interface identity, spoken tabulated-list navigation, refresh preservation, and dismissal feedback for the aural managers and editors.

2.50.1 Emacsvox-Aural-Ui Commands

2.50.1.1 emacsvox-aural-interface-mode

Command: emacsvox-aural-interface-mode
Base mode for non-tabulated aural interfaces.

In addition to any hooks its parent mode ‘special-mode’ might have
run, this mode runs the hook ‘emacsvox-aural-interface-mode-hook’, as
the final or penultimate step during initialization.

Key             Binding
——————————————————————————-
SPC		scroll-up-command
-		negative-argument
0 .. 9		digit-argument
<		beginning-of-buffer
>		end-of-buffer
?		describe-mode
g		revert-buffer
h		describe-mode
q		emacsvox-aural-quit
DEL		scroll-down-command
S-SPC		scroll-down-command

2.50.1.2 emacsvox-aural-quit

Command: emacsvox-aural-quit (&optional kill)
Dismiss the current aural interface and report its destination.

When KILL is non-nil, kill the interface buffer as ‘quit-window’ would.

(fn &optional KILL)

2.50.1.3 emacsvox-aural-tabulated-mode

Command: emacsvox-aural-tabulated-mode
Base mode for spoken tabulated aural interfaces.

In addition to any hooks its parent mode ‘tabulated-list-mode’ might
have run, this mode runs the hook
‘emacsvox-aural-tabulated-mode-hook’, as the final or penultimate step
during initialization.

Key             Binding
——————————————————————————-
TAB		forward-button
C-n		emacsvox-aural-ui-next-row
C-p		emacsvox-aural-ui-previous-row
SPC		emacsvox-aural-ui-speak-current-row
-		negative-argument
.		emacsvox-aural-ui-speak-current-cell
0 .. 9		digit-argument
<		beginning-of-buffer
>		end-of-buffer
?		describe-mode
S		tabulated-list-sort
g		emacsvox-aural-ui-refresh
h		describe-mode
n		emacsvox-aural-ui-next-row
p		emacsvox-aural-ui-previous-row
q		emacsvox-aural-quit
{		tabulated-list-narrow-current-column
}		tabulated-list-widen-current-column
DEL		scroll-down-command
S-SPC		scroll-down-command
M-<left>	tabulated-list-previous-column
M-<right>	tabulated-list-next-column
<backtab>	backward-button
<down>		emacsvox-aural-ui-next-row
<follow-link>	mouse-face
<left>		emacsvox-aural-ui-previous-column
<mouse-2>	mouse-select-window
<right>		emacsvox-aural-ui-next-column
<up>		emacsvox-aural-ui-previous-row

C-M-i		backward-button

2.50.1.4 emacsvox-aural-ui-help-quit

Command: emacsvox-aural-ui-help-quit
Quit Help and restore its originating aural interface and position.

2.50.1.5 emacsvox-aural-ui-help-return-mode

Command: emacsvox-aural-ui-help-return-mode (&optional arg)
Return from Help to the exact aural interface that requested it.

This is a minor mode.  If called interactively, toggle the
‘Emacsvox-Aural-Ui-Help-Return mode’ mode.  If the prefix argument is
positive, enable the mode, and if it is zero or negative, disable the
mode.

If called from Lisp, toggle the mode if ARG is ‘toggle’.  Enable the
mode if ARG is nil, omitted, or is a positive number.  Disable the mode
if ARG is a negative number.

To check whether the minor mode is enabled in the current buffer,
evaluate the variable ‘emacsvox-aural-ui-help-return-mode’.

The mode’s hook is called both when the mode is enabled and when it is
disabled.

(fn &optional ARG)

2.50.1.6 emacsvox-aural-ui-next-column

Command: emacsvox-aural-ui-next-column
Move right and speak the next column.

2.50.1.7 emacsvox-aural-ui-next-row

Command: emacsvox-aural-ui-next-row
Move to and speak the next row.

2.50.1.8 emacsvox-aural-ui-previous-column

Command: emacsvox-aural-ui-previous-column
Move left and speak the previous column.

2.50.1.9 emacsvox-aural-ui-previous-row

Command: emacsvox-aural-ui-previous-row
Move to and speak the previous row.

2.50.1.10 emacsvox-aural-ui-refresh

Command: emacsvox-aural-ui-refresh
Refresh the current interface using its configured callback.

2.50.1.11 emacsvox-aural-ui-speak-current-cell

Command: emacsvox-aural-ui-speak-current-cell (&optional value-first)
Speak the current tabulated cell.

Speak its column title first by default.  When VALUE-FIRST is non-nil, speak
the cell value first.

(fn &optional VALUE-FIRST)

2.50.1.12 emacsvox-aural-ui-speak-current-row

Command: emacsvox-aural-ui-speak-current-row
Speak the complete current row using its configured callback.

2.50.2 emacsvox-aural-ui Options

Variable: User Option emacsvox-aural-ui-help-return-mode-hook
Hook run after entering or leaving ‘emacsvox-aural-ui-help-return-mode’.
No problems result if this variable is not bound.
‘add-hook’ automatically binds it.  (This is true for all hook variables.)

Default Value:

nil