2.52 emacsvox-aural-voice-palettes

Accessible management for inherited, data-safe ACSS voice palettes.

2.52.1 Emacsvox-Aural-Voice-Palettes Commands

2.52.1.1 emacsvox-aural-list-voice-palettes

Command: emacsvox-aural-list-voice-palettes (&optional palette)
Open the spoken manager for voice PALETTE providers.

(fn &optional PALETTE)

2.52.1.2 emacsvox-aural-voice-palette-previews-copy

Command: emacsvox-aural-voice-palette-previews-copy
Copy the current voice to a new, independently routable voice.

2.52.1.3 emacsvox-aural-voice-palette-previews-edit

Command: emacsvox-aural-voice-palette-previews-edit
Replace the effective voice at point using the guided definition editor.

2.52.1.4 emacsvox-aural-voice-palette-previews-explain

Command: emacsvox-aural-voice-palette-previews-explain
Explain the effective voice at point.

2.52.1.5 emacsvox-aural-voice-palette-previews-help

Command: emacsvox-aural-voice-palette-previews-help
Display and speak voice-palette preview help.

2.52.1.6 emacsvox-aural-voice-palette-previews-mode

Command: emacsvox-aural-voice-palette-previews-mode
Spoken browser for effective voices in one palette.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-voice-palette-previews-mode-hook’, as the final
or penultimate step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-voice-palette-previews-play
?		emacsvox-aural-voice-palette-previews-help
A		emacsvox-aural-voice-palette-previews-play-all
E		emacsvox-aural-voice-palette-previews-edit
N		emacsvox-aural-voice-palette-previews-new
P		emacsvox-aural-voice-palette-previews-play
S		emacsvox-aural-voice-palette-previews-stop
T		emacsvox-aural-voice-palette-previews-set-text
c		emacsvox-aural-voice-palette-previews-copy
e		emacsvox-aural-voice-palette-previews-tune
h		emacsvox-aural
o		emacsvox-aural-voice-palette-previews-open-manager
s		emacsvox-aural-voice-palette-previews-stop
t		emacsvox-aural-voice-palette-previews-tune
x		emacsvox-aural-voice-palette-previews-explain

2.52.1.7 emacsvox-aural-voice-palette-previews-new

Command: emacsvox-aural-voice-palette-previews-new
Create a new voice in the palette shown by the current preview.

2.52.1.8 emacsvox-aural-voice-palette-previews-next

Command: emacsvox-aural-voice-palette-previews-next
Move to and speak the next effective voice.

2.52.1.9 emacsvox-aural-voice-palette-previews-next-column

Command: emacsvox-aural-voice-palette-previews-next-column
Move right and speak the next voice column.

2.52.1.10 emacsvox-aural-voice-palette-previews-open-manager

Command: emacsvox-aural-voice-palette-previews-open-manager
Return to the palette manager for the current preview palette.

2.52.1.11 emacsvox-aural-voice-palette-previews-play

Command: emacsvox-aural-voice-palette-previews-play
Audition the effective voice at point with the comparison text.

2.52.1.12 emacsvox-aural-voice-palette-previews-play-all

Command: emacsvox-aural-voice-palette-previews-play-all
Audition every effective voice using the same comparison text.

2.52.1.13 emacsvox-aural-voice-palette-previews-previous

Command: emacsvox-aural-voice-palette-previews-previous
Move to and speak the previous effective voice.

2.52.1.14 emacsvox-aural-voice-palette-previews-previous-column

Command: emacsvox-aural-voice-palette-previews-previous-column
Move left and speak the previous voice column.

2.52.1.15 emacsvox-aural-voice-palette-previews-refresh

Command: emacsvox-aural-voice-palette-previews-refresh (&optional voice)
Refresh palette voices, preserving VOICE and the current column.

(fn &optional VOICE)

2.52.1.16 emacsvox-aural-voice-palette-previews-set-text

Command: emacsvox-aural-voice-palette-previews-set-text
Set the comparison text used by this preview buffer.

2.52.1.17 emacsvox-aural-voice-palette-previews-speak-current

Command: emacsvox-aural-voice-palette-previews-speak-current
Speak the complete palette voice row at point.

2.52.1.18 emacsvox-aural-voice-palette-previews-speak-current-cell

Command: emacsvox-aural-voice-palette-previews-speak-current-cell
Speak the current preview column title and value.

2.52.1.19 emacsvox-aural-voice-palette-previews-stop

Command: emacsvox-aural-voice-palette-previews-stop
Stop the current voice audition.

2.52.1.20 emacsvox-aural-voice-palette-previews-tune

Command: emacsvox-aural-voice-palette-previews-tune
Open a transactional tuner for the effective voice at point.

2.52.1.21 emacsvox-aural-voice-palettes-activate

Command: emacsvox-aural-voice-palettes-activate
Activate the voice palette at point as an override.

2.52.1.22 emacsvox-aural-voice-palettes-copy

Command: emacsvox-aural-voice-palettes-copy
Copy the voice palette at point to a personal palette.

2.52.1.23 emacsvox-aural-voice-palettes-create

Command: emacsvox-aural-voice-palettes-create
Create an empty personal voice palette.

2.52.1.24 emacsvox-aural-voice-palettes-delete

Command: emacsvox-aural-voice-palettes-delete
Delete the personal voice palette at point when it is unreferenced.

2.52.1.25 emacsvox-aural-voice-palettes-delete-entry

Command: emacsvox-aural-voice-palettes-delete-entry
Delete one direct entry from the personal palette at point.

2.52.1.26 emacsvox-aural-voice-palettes-describe

Command: emacsvox-aural-voice-palettes-describe (&optional id)
Display and speak the effective voices in palette ID.

(fn &optional ID)

2.52.1.27 emacsvox-aural-voice-palettes-edit-entry

Command: emacsvox-aural-voice-palettes-edit-entry
Create or replace one direct voice entry in the personal palette at point.

2.52.1.28 emacsvox-aural-voice-palettes-edit-metadata

Command: emacsvox-aural-voice-palettes-edit-metadata
Edit summary and parent of the personal palette at point.

2.52.1.29 emacsvox-aural-voice-palettes-explain

Command: emacsvox-aural-voice-palettes-explain (&optional id voice)
Explain one effective voice and its adapter fallback.

(fn &optional ID VOICE)

2.52.1.30 emacsvox-aural-voice-palettes-follow-baseline

Command: emacsvox-aural-voice-palettes-follow-baseline
Clear the palette override and use the compatibility baseline.

2.52.1.31 emacsvox-aural-voice-palettes-help

Command: emacsvox-aural-voice-palettes-help
Display and speak voice-palette manager help.

2.52.1.32 emacsvox-aural-voice-palettes-mode

Command: emacsvox-aural-voice-palettes-mode
Spoken manager for inherited ACSS voice palettes.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-voice-palettes-mode-hook’, as the final or
penultimate step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-voice-palettes-preview
?		emacsvox-aural-voice-palettes-help
B		emacsvox-aural-voice-palettes-preview
D		emacsvox-aural-voice-palettes-delete-entry
E		emacsvox-aural-voice-palettes-edit-metadata
N		emacsvox-aural-voice-palettes-create
P		emacsvox-aural-voice-palettes-preview
a		emacsvox-aural-voice-palettes-activate
c		emacsvox-aural-voice-palettes-copy
d		emacsvox-aural-voice-palettes-delete
e		emacsvox-aural-voice-palettes-edit-entry
f		emacsvox-aural-voice-palettes-follow-baseline
h		emacsvox-aural
v		emacsvox-aural-voice-palettes-describe
x		emacsvox-aural-voice-palettes-explain

2.52.1.33 emacsvox-aural-voice-palettes-next

Command: emacsvox-aural-voice-palettes-next
Move to and speak the next voice palette.

2.52.1.34 emacsvox-aural-voice-palettes-next-column

Command: emacsvox-aural-voice-palettes-next-column
Move right and speak the next palette column.

2.52.1.35 emacsvox-aural-voice-palettes-preview

Command: emacsvox-aural-voice-palettes-preview (&optional id)
Browse and audition all effective voices in palette ID or at point.

(fn &optional ID)

2.52.1.36 emacsvox-aural-voice-palettes-previous

Command: emacsvox-aural-voice-palettes-previous
Move to and speak the previous voice palette.

2.52.1.37 emacsvox-aural-voice-palettes-previous-column

Command: emacsvox-aural-voice-palettes-previous-column
Move left and speak the previous palette column.

2.52.1.38 emacsvox-aural-voice-palettes-refresh

Command: emacsvox-aural-voice-palettes-refresh (&optional id)
Refresh palettes while preserving ID and the current column.

(fn &optional ID)

2.52.1.39 emacsvox-aural-voice-palettes-speak-current

Command: emacsvox-aural-voice-palettes-speak-current
Speak the complete voice-palette row at point.

2.52.1.40 emacsvox-aural-voice-palettes-speak-current-cell

Command: emacsvox-aural-voice-palettes-speak-current-cell
Speak the current palette column title and value.

2.52.1.41 emacsvox-aural-voice-tuner-audition

Command: emacsvox-aural-voice-tuner-audition (&optional announcement)
Audition the unsaved working style after optional ANNOUNCEMENT.

(fn &optional ANNOUNCEMENT)

2.52.1.42 emacsvox-aural-voice-tuner-decrease

Command: emacsvox-aural-voice-tuner-decrease
Decrease the current numeric dimension and audition its new value.

2.52.1.43 emacsvox-aural-voice-tuner-edit

Command: emacsvox-aural-voice-tuner-edit
Edit the current dimension and audition the new value.

2.52.1.44 emacsvox-aural-voice-tuner-help

Command: emacsvox-aural-voice-tuner-help
Display and speak voice tuner help.

2.52.1.45 emacsvox-aural-voice-tuner-increase

Command: emacsvox-aural-voice-tuner-increase
Increase the current numeric dimension and audition its new value.

2.52.1.46 emacsvox-aural-voice-tuner-mode

Command: emacsvox-aural-voice-tuner-mode
Transactional spoken tuner for one personal-palette voice.

In addition to any hooks its parent mode
‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the
hook ‘emacsvox-aural-voice-tuner-mode-hook’, as the final or
penultimate step during initialization.

Key             Binding
——————————————————————————-
RET		emacsvox-aural-voice-tuner-edit
+		emacsvox-aural-voice-tuner-increase
-		emacsvox-aural-voice-tuner-decrease
0 .. 9		emacsvox-aural-voice-tuner-set-digit
?		emacsvox-aural-voice-tuner-help
P		emacsvox-aural-voice-tuner-audition
R		emacsvox-aural-voice-tuner-restore
d		emacsvox-aural-voice-tuner-use-default
e		emacsvox-aural-voice-tuner-edit
h		emacsvox-aural
q		emacsvox-aural-voice-tuner-quit
u		emacsvox-aural-voice-tuner-undo
w		emacsvox-aural-voice-tuner-save
<left>		emacsvox-aural-voice-tuner-decrease
<right>		emacsvox-aural-voice-tuner-increase

C-c C-c		emacsvox-aural-voice-tuner-save
C-c C-k		emacsvox-aural-voice-tuner-quit

2.52.1.47 emacsvox-aural-voice-tuner-next

Command: emacsvox-aural-voice-tuner-next
Move to and speak the next tunable dimension.

2.52.1.48 emacsvox-aural-voice-tuner-previous

Command: emacsvox-aural-voice-tuner-previous
Move to and speak the previous tunable dimension.

2.52.1.49 emacsvox-aural-voice-tuner-quit

Command: emacsvox-aural-voice-tuner-quit
Cancel tuning, asking before discarding unsaved changes.

2.52.1.50 emacsvox-aural-voice-tuner-refresh

Command: emacsvox-aural-voice-tuner-refresh (&optional dimension)
Refresh the tuner while preserving DIMENSION and the current column.

(fn &optional DIMENSION)

2.52.1.51 emacsvox-aural-voice-tuner-restore

Command: emacsvox-aural-voice-tuner-restore
Restore and audition the style present when the tuner opened.

2.52.1.52 emacsvox-aural-voice-tuner-save

Command: emacsvox-aural-voice-tuner-save
Atomically save the portable style and return to the voice preview.

2.52.1.53 emacsvox-aural-voice-tuner-set-digit

Command: emacsvox-aural-voice-tuner-set-digit
Set the current numeric dimension from the typed digit and audition it.

2.52.1.54 emacsvox-aural-voice-tuner-speak-current

Command: emacsvox-aural-voice-tuner-speak-current
Speak the complete tuner row at point.

2.52.1.55 emacsvox-aural-voice-tuner-undo

Command: emacsvox-aural-voice-tuner-undo
Undo the most recent unsaved tuner change and audition it.

2.52.1.56 emacsvox-aural-voice-tuner-use-default

Command: emacsvox-aural-voice-tuner-use-default
Use the adapter default for the current dimension and audition it.

2.52.2 emacsvox-aural-voice-palettes Options

Variable: User Option emacsvox-aural-voice-palettes-preview-text
Comparison text used when auditioning voices from a palette.

Default Value:

"The quick brown fox jumps over the lazy dog. Numbers one, two, three."