2.58 emacsvox-bookshare

BOOKSHARE == http://www.bookshare.org provides book access to print-disabled users. It provides a simple Web API http://developer.bookshare.org This module implements an Emacsvox Bookshare client.

2.58.1 requirements

2.58.2 Usage

The main entry point is command emacsvox-bookshare bound to C-e C-b. This creates a special Bookshare Interaction buffer that is placed in emacsvox-bookshare-mode. Se the help for that mode on detailed usage instructions and key-bindings.

2.58.3 Sample Interaction

Assuming you have correctly setup your API key:

2.58.4 Emacsvox-Bookshare Commands

2.58.4.1 emacsvox-bookshare

Command: emacsvox-bookshare
C-e C-b
Bookshare  Interaction.

2.58.4.2 emacsvox-bookshare-action

Command: emacsvox-bookshare-action
Call action specified by  invoking key.

2.58.4.3 emacsvox-bookshare-author-search

Command: emacsvox-bookshare-author-search (query &optional category)
Perform a Bookshare author search.
Interactive prefix arg filters search by category.

(fn QUERY &optional CATEGORY)

2.58.4.4 emacsvox-bookshare-browse

Command: emacsvox-bookshare-browse
Browse Bookshare.

2.58.4.5 emacsvox-bookshare-browse-latest

Command: emacsvox-bookshare-browse-latest
Return latest books.

2.58.4.6 emacsvox-bookshare-browse-popular

Command: emacsvox-bookshare-browse-popular (&optional category)
Browse popular books.
Optional interactive prefix arg prompts for a category to use as a filter.

(fn &optional CATEGORY)

2.58.4.7 emacsvox-bookshare-debugInfo-handler

Command: emacsvox-bookshare-debugInfo-handler (&rest arguments)
Ignore ARGUMENTS, do nothing, and return nil.
This function accepts any number of arguments in ARGUMENTS.
Also see ‘always’.

(fn &rest ARGUMENTS)

2.58.4.8 emacsvox-bookshare-download-audio

Command: emacsvox-bookshare-download-audio (id target)
Download audio format of specified book to target location.

(fn ID TARGET)

2.58.4.9 emacsvox-bookshare-download-audio-at-point

Command: emacsvox-bookshare-download-audio-at-point
Download audio version of book under point.
Target location is generated from author and title.

2.58.4.10 emacsvox-bookshare-download-brf

Command: emacsvox-bookshare-download-brf (id target)
Download Daisy format of specified book to target location.

(fn ID TARGET)

2.58.4.11 emacsvox-bookshare-download-brf-at-point

Command: emacsvox-bookshare-download-brf-at-point
Download Braille version of book under point.
Target location is generated from author and title.

2.58.4.12 emacsvox-bookshare-download-daisy

Command: emacsvox-bookshare-download-daisy (id target)
Download Daisy format of specified book to target location.

(fn ID TARGET)

2.58.4.13 emacsvox-bookshare-download-daisy-at-point

Command: emacsvox-bookshare-download-daisy-at-point
Download Daisy version of book under point.
Target location is generated from author and title.

2.58.4.14 emacsvox-bookshare-download-epub-3

Command: emacsvox-bookshare-download-epub-3 (id target)
Download epub-3 format of specified book to target location.

(fn ID TARGET)

2.58.4.15 emacsvox-bookshare-download-epub-3-at-point

Command: emacsvox-bookshare-download-epub-3-at-point
Download epub-3 version of book under point.
Target location is generated from author and title.

2.58.4.16 emacsvox-bookshare-download-internal

Command: emacsvox-bookshare-download-internal (url target)
Download content  to target location.

(fn URL TARGET)

2.58.4.17 emacsvox-bookshare-eww

Command: emacsvox-bookshare-eww (directory)
C-e y b
Render  book using EWW

(fn DIRECTORY)

2.58.4.18 emacsvox-bookshare-expand-at-point

Command: emacsvox-bookshare-expand-at-point
Expand entry at point by retrieving metadata.
Once retrieved, memoize to avoid multiple retrievals.

2.58.4.19 emacsvox-bookshare-extract-and-view

Command: emacsvox-bookshare-extract-and-view (url)
Extract content referred to by link under point, and render via the browser.

(fn URL)

2.58.4.20 emacsvox-bookshare-extract-xml

Command: emacsvox-bookshare-extract-xml (url)
Extract content referred to by link under point, and return an XML buffer.

(fn URL)

2.58.4.21 emacsvox-bookshare-flush-lines

Command: emacsvox-bookshare-flush-lines (regexp)
Flush lines matching regexp in Bookshare buffer.

(fn REGEXP)

2.58.4.22 emacsvox-bookshare-fulltext

Command: emacsvox-bookshare-fulltext (directory)
Display fulltext contents of  book in specified directory.
Useful for fulltext search in a book.

(fn DIRECTORY)

2.58.4.23 emacsvox-bookshare-fulltext-search

Command: emacsvox-bookshare-fulltext-search (query)
Perform a Bookshare fulltext search.

(fn QUERY)

2.58.4.24 emacsvox-bookshare-get-more-results

Command: emacsvox-bookshare-get-more-results
Get next page of results for last query.

2.58.4.25 emacsvox-bookshare-id-search

Command: emacsvox-bookshare-id-search (query)
Perform a Bookshare id search.

(fn QUERY)

2.58.4.26 emacsvox-bookshare-isbn-search

Command: emacsvox-bookshare-isbn-search (query)
Perform a Bookshare isbn search.

(fn QUERY)

2.58.4.27 emacsvox-bookshare-list-preferences

Command: emacsvox-bookshare-list-preferences
Return preference list.

2.58.4.28 emacsvox-bookshare-mode

Command: emacsvox-bookshare-mode
A Bookshare front-end for the Emacsvox desktop.

The Emacsvox Bookshare front-end is launched by command
emacsvox-bookshare bound to C-e C-b

This command switches to a special buffer that has Bookshare
commands bounds to single keystrokes– see the key-binding list at
the end of this description. Use Emacs online help facility to
look up help on these commands.

emacsvox-bookshare-mode provides the necessary functionality to
Search and download Bookshare material, Manage a local library of
downloaded Bookshare content, And commands to easily read newer
Daisy books from Bookshare.

Here is a list of all emacsvox Bookshare commands  with their key-bindings:
a Author Search
A Author/Title Search
t Title Search
s Full Text Search
d Date Search
b Browse

Key             Binding
——————————————————————————-
RET		emacsvox-bookshare-toc-at-point
SPC		emacsvox-bookshare-expand-at-point
+		emacsvox-bookshare-action
/		emacsvox-bookshare-action
3		emacsvox-bookshare-download-epub-3-at-point
A		emacsvox-bookshare-download-audio-at-point
B		emacsvox-bookshare-download-brf-at-point
C		emacsvox-bookshare-fulltext
D		emacsvox-bookshare-download-daisy-at-point
E		emacsvox-bookshare-eww
I		emacsvox-bookshare-action
P		emacsvox-bookshare-action
S		emacsvox-bookshare-action
U		emacsvox-bookshare-unpack-at-point
V		emacsvox-bookshare-view-at-point
[		backward-page
]		forward-page
a		emacsvox-bookshare-action
b		emacsvox-bookshare-browse
c		emacsvox-bookshare-toc-at-point
d		emacsvox-bookshare-action
e		emacsvox-bookshare-eww
f		emacsvox-bookshare-flush-lines
i		emacsvox-bookshare-action
j		next-line
k		previous-line
l .. m		emacsvox-bookshare-action
n		emacsvox-bookshare-next-result
p		emacsvox-bookshare-previous-result
q		bury-buffer
s .. t		emacsvox-bookshare-action
v		emacsvox-bookshare-view

M-n		emacsvox-bookshare-next-result
M-p		emacsvox-bookshare-previous-result

In addition to any hooks its parent mode ‘special-mode’ might have
run, this mode runs the hook ‘emacsvox-bookshare-mode-hook’, as the
final or penultimate step during initialization.

2.58.4.29 emacsvox-bookshare-next-result

Command: emacsvox-bookshare-next-result
Move to next result.

2.58.4.30 emacsvox-bookshare-periodical-list

Command: emacsvox-bookshare-periodical-list
Return list of periodicals.

2.58.4.31 emacsvox-bookshare-previous-result

Command: emacsvox-bookshare-previous-result
Move to previous result.

2.58.4.32 emacsvox-bookshare-set-preference

Command: emacsvox-bookshare-set-preference (preference-id value)
Set preference preference-id to value.

(fn PREFERENCE-ID VALUE)

2.58.4.33 emacsvox-bookshare-since-search

Command: emacsvox-bookshare-since-search (query &optional category)
Perform a Bookshare date  search.
Optional interactive prefix arg filters by category.

(fn QUERY &optional CATEGORY)

2.58.4.34 emacsvox-bookshare-title-search

Command: emacsvox-bookshare-title-search (query &optional category)
Perform a Bookshare title search.
Interactive prefix arg filters search by category.

(fn QUERY &optional CATEGORY)

2.58.4.35 emacsvox-bookshare-toc

Command: emacsvox-bookshare-toc (directory)
View TOC for book in specified directory.

(fn DIRECTORY)

2.58.4.36 emacsvox-bookshare-toc-at-point

Command: emacsvox-bookshare-toc-at-point
View TOC for book at point.
Make sure it’s downloaded and unpacked first.

2.58.4.37 emacsvox-bookshare-unpack-at-point

Command: emacsvox-bookshare-unpack-at-point
Unpack downloaded content if necessary.

2.58.4.38 emacsvox-bookshare-url-executor

Command: emacsvox-bookshare-url-executor (url)
Custom URL executor for use in Bookshare TOC.

(fn URL)

2.58.4.39 emacsvox-bookshare-version-handler

Command: emacsvox-bookshare-version-handler (&rest arguments)
Ignore ARGUMENTS, do nothing, and return nil.
This function accepts any number of arguments in ARGUMENTS.
Also see ‘always’.

(fn &rest ARGUMENTS)

2.58.4.40 emacsvox-bookshare-view

Command: emacsvox-bookshare-view (directory)
View book in specified directory.

(fn DIRECTORY)

2.58.4.41 emacsvox-bookshare-view-at-point

Command: emacsvox-bookshare-view-at-point
View book at point.
Make sure it’s downloaded and unpacked first.

2.58.4.42 emacsvox-bookshare-view-page-range

Command: emacsvox-bookshare-view-page-range (url)
Play pages in specified page range from URL.

(fn URL)

2.58.5 emacsvox-bookshare Options

Variable: User Option emacsvox-bookshare-api-key
Web API  key for this application.
See http://developer.bookshare.org/docs for details on how to get
  an API key.

Default Value:

nil

Variable: User Option emacsvox-bookshare-directory
Customize this to the root of where books are organized.

Default Value:

"~/books/book-share"