2.65 emacsvox-calendar

This module speech enables the Emacs Calendar. Speech enabling is not the same as speaking the screen: This is an excellent example of the advantages of speech-enabled interaction.

2.65.1 Emacsvox-Calendar Commands

2.65.1.1 emacsvox-appt-repeat-announcement

Command: emacsvox-appt-repeat-announcement
C-e A
Speaks the most recently displayed appointment message if any.

2.65.1.2 emacsvox-calendar-setup-sunrise-sunset

Command: emacsvox-calendar-setup-sunrise-sunset
Set up geo-coordinates using Google Maps reverse geocoding.
To use, configure variable gmaps-my-address via M-x customize-variable.

2.65.1.3 emacsvox-calendar-speak-date

Command: emacsvox-calendar-speak-date
Speak the date under point when called in Calendar Mode.

2.65.1.4 emacsvox-calendar-sunrise-sunset

Command: emacsvox-calendar-sunrise-sunset (address &optional arg)
Display sunrise/sunset for specified address.

(fn ADDRESS &optional ARG)