2.67 emacsvox-chess

The Emacs Chess package provides a rich environment for playing and exploring Chess Games. That package comes with a light-weight module that announces moves.

This module aims to do much more, including:

2.67.2 Examining Games

Package Chess allows one to browse through a game using , and .chess-display-move-backward and chess-display-move-forward. Emacsvox speech-enables these commands to speak the move that led to the currently displayed state of the game. Finally, m speaks the current move being displayed.

2.67.3 Emacsvox-Chess Commands

2.67.3.1 emacsvox-chess-east

Command: emacsvox-chess-east
Move east one step.

2.67.3.2 emacsvox-chess-goto-target

Command: emacsvox-chess-goto-target
Jump to the most recent target square.

2.67.3.3 emacsvox-chess-jump

Command: emacsvox-chess-jump (coord)
Jump to square specified as coord.

(fn COORD)

2.67.3.4 emacsvox-chess-look-east

Command: emacsvox-chess-look-east
Look east

2.67.3.5 emacsvox-chess-look-king

Command: emacsvox-chess-look-king
Look along non-empty squares reachable by the king  from current position.

2.67.3.6 emacsvox-chess-look-knight

Command: emacsvox-chess-look-knight
Look along non-empty squares reachable by a knight from current position.

2.67.3.7 emacsvox-chess-look-north

Command: emacsvox-chess-look-north
Look north

2.67.3.8 emacsvox-chess-look-northeast

Command: emacsvox-chess-look-northeast
Look northeast

2.67.3.9 emacsvox-chess-look-northwest

Command: emacsvox-chess-look-northwest
Look northwest

2.67.3.10 emacsvox-chess-look-south

Command: emacsvox-chess-look-south
Look south

2.67.3.11 emacsvox-chess-look-southeast

Command: emacsvox-chess-look-southeast
Look southeast

2.67.3.12 emacsvox-chess-look-southwest

Command: emacsvox-chess-look-southwest
Look southwest

2.67.3.13 emacsvox-chess-look-west

Command: emacsvox-chess-look-west
Look west

2.67.3.14 emacsvox-chess-north

Command: emacsvox-chess-north
Move north one step.

2.67.3.15 emacsvox-chess-northeast

Command: emacsvox-chess-northeast
Move northeast one step.

2.67.3.16 emacsvox-chess-northwest

Command: emacsvox-chess-northwest
Move northwest one step.

2.67.3.17 emacsvox-chess-south

Command: emacsvox-chess-south
Move south one step.

2.67.3.18 emacsvox-chess-southeast

Command: emacsvox-chess-southeast
Move southeast one step.

2.67.3.19 emacsvox-chess-southwest

Command: emacsvox-chess-southwest
Move southwest one step.

2.67.3.20 emacsvox-chess-speak-board

Command: emacsvox-chess-speak-board
Speak complete board. Only useful in end-states.

2.67.3.21 emacsvox-chess-speak-piece-squares

Command: emacsvox-chess-speak-piece-squares (piece)
Prompt for a piece (single char) and speak its locations on the
  board.  Piece is specified as a char using SAN notation. Use
  ‘w’ for all whites pieces,  ‘l’ for all black pieces,
and ‘a’ for entire board..

(fn PIECE)

2.67.3.22 emacsvox-chess-speak-that-square

Command: emacsvox-chess-speak-that-square (coord)
Speak square at specified coord.

(fn COORD)

2.67.3.23 emacsvox-chess-speak-this-move

Command: emacsvox-chess-speak-this-move
Speak move at current display index.

2.67.3.24 emacsvox-chess-speak-this-square

Command: emacsvox-chess-speak-this-square
Speak square under point.

2.67.3.25 emacsvox-chess-speak-who-targets

Command: emacsvox-chess-speak-who-targets (piece)
Speak description of squares that can target current square.
Argument ‘piece’ specifies  piece-or-color as in command
  emacsvox-chess-speak-piece-squares

(fn PIECE)

2.67.3.26 emacsvox-chess-view-rank-or-file

Command: emacsvox-chess-view-rank-or-file
View a complete rank or file from white’s perspective.

2.67.3.27 emacsvox-chess-west

Command: emacsvox-chess-west
Move west one step.