2.72 emacsvox-comint

comint == command interaction. Advice comint and friends to speak.

2.72.1 Emacsvox-Comint Commands

2.72.1.1 emacsvox-toggle-comint-autospeak

Command: emacsvox-toggle-comint-autospeak (&optional prefix)
Toggle comint autospeak.
Interactive PREFIX arg means toggle  global default value.

(fn &optional PREFIX)

2.72.1.2 emacsvox-toggle-comint-output-monitor

Command: emacsvox-toggle-comint-output-monitor (&optional prefix)
C-e M-o
Toggle whether autospeech follows this Comint buffer in the background.
Interactive PREFIX toggles the global default and applies it locally.

(fn &optional PREFIX)

2.72.1.3 emacsvox-toggle-inaudible-or-comint-autospeak

Command: emacsvox-toggle-inaudible-or-comint-autospeak
C-e C-q
Toggle comint-autospeak when in a comint or vterm buffer.
Otherwise call voice-setup-toggle-silence-personality which
toggles personality under point.

2.72.1.4 emacsvox-zoxide

Command: emacsvox-zoxide (q)
C-; j
C-x @ h j
Query zoxide  and launch dired.
Shell Utility zoxide — implemented in Rust — lets you jump to
directories that are used often.

(fn Q)

2.72.2 emacsvox-comint Options

Variable: User Option emacsvox-comint-autospeak
Speak comint output.
Use M-x emacsvox-toggle-comint-autospeak to toggle this
setting. Do not set this globally. Also see custom option
‘emacsvox-wizards-project-shells’ for starting up
project-specific shells that have autospeak turned on. The
default is intentionally nil, since this option should only be
turned on where needed.

Default Value:

nil