2.78 emacsvox-custom

Advise custom to speak. most of the work is actually done by emacsvox-widget.el which speech-enables the widget libraries.

2.78.1 Emacsvox-Custom Commands

2.78.1.1 emacsvox-custom-goto-group

Command: emacsvox-custom-goto-group
Jump to custom group when in a customization buffer.

2.78.1.2 emacsvox-custom-goto-toolbar

Command: emacsvox-custom-goto-toolbar
Jump to custom toolbar when in a customization buffer.