Loading this module sets up Emacsvox to respond to DBus notifications. This module needs to be loaded explicitly from the user’s init file after emacsvox has been started.
This module provides integration via DBus for the following:
(nm-enable).
(emacsvox-dbus-watch-screen-lock).
(emacsvox-dbus-sleep-enable).
(emacsvox-dbus-udisks-enable).
(emacsvox-dbus-upower-enable).
emacsvox-dbus-lock-screen
bound to C-, C-d to lock the screen using DBus.
Note: this key-binding is available only if this module is loaded.
Add calls to the desired functions from the above list to the emacs startup file after this module has been loaded. To enable all of them, add (emacsvox-dbus-setup). See relevant hooks for customizing behavior. Note that each of the sleep/wake-up, UDisks2 and network/up-down can be separately enabled/disabled, and the actions customized via appropriately named hook functions.
Disable integration with login1 daemon. Does nothing if already disabled.
Enable integration with Login1. Does nothing if already enabled.
Disable integration with UDisks2 daemon. Does nothing if already disabled.
Enable integration with UDisks2. Does nothing if already enabled.
Disable integration with UPower daemon. Does nothing if already disabled.
Enable integration with UPower. Does nothing if already enabled.
A light-weight mode for the ‘*Emacsvox Screen Saver *’ buffer. This is a hidden buffer that is made current so we automatically switch to a screen-saver soundscape. In addition to any hooks its parent mode ‘special-mode’ might have run, this mode runs the hook ‘emacsvox-screen-saver-mode-hook’, as the final or penultimate step during initialization.