2.87 emacsvox-dired

This module speech enables dired. It reduces the amount of speech you hear: Typically you hear the file names as you move through the dired buffer Voicification is used to indicate directories, marked files etc.

2.87.1 Emacsvox-Dired Commands

2.87.1.1 emacsvox-dired-csv-open

Command: emacsvox-dired-csv-open
Open CSV file on current dired line.

2.87.1.2 emacsvox-dired-downloads

Command: emacsvox-dired-downloads
C-. d
C-x @ s d
Open Downloads directory.

2.87.1.3 emacsvox-dired-epub-eww

Command: emacsvox-dired-epub-eww
Open epub on current line  in EWW

2.87.1.4 emacsvox-dired-eww-open

Command: emacsvox-dired-eww-open
Open HTML file on current dired line.

2.87.1.5 emacsvox-dired-label-fields

Command: emacsvox-dired-label-fields
Labels the fields of the listing in the dired buffer.
Currently is a no-op  unless
unless ‘dired-listing-switches’ contains -l

2.87.1.6 emacsvox-dired-md-open

Command: emacsvox-dired-md-open
Preview markdown  file on current dired line.

2.87.1.7 emacsvox-dired-midi-play

Command: emacsvox-dired-midi-play
Play midi  file on current dired line.

2.87.1.8 emacsvox-dired-open-this-directory

Command: emacsvox-dired-open-this-directory
Open directory corresponding to file on current line.

2.87.1.9 emacsvox-dired-open-this-file

Command: emacsvox-dired-open-this-file
Smart dired opener. Invokes appropriate Emacsvox handler on
current file in DirEd.

2.87.1.10 emacsvox-dired-pdf-open

Command: emacsvox-dired-pdf-open
Open PDF file on current dired line.

2.87.1.11 emacsvox-dired-play-duration

Command: emacsvox-dired-play-duration
Speak duration of sound files.
If on a file, speak its duration.
If on a directory, speak the total duration of all sound files under
  that directory.

2.87.1.12 emacsvox-dired-rpm-query-in-dired

Command: emacsvox-dired-rpm-query-in-dired
Run rpm -qi on current dired entry.

2.87.1.13 emacsvox-dired-show-file-type

Command: emacsvox-dired-show-file-type (&optional file deref-symlinks)
Displays type of current file by running command file.
Like Emacs’ built-in dired-show-file-type but allows user to customize
options passed to command ‘file’.

(fn &optional FILE DEREF-SYMLINKS)

2.87.1.14 emacsvox-dired-speak-file-access-time

Command: emacsvox-dired-speak-file-access-time
Speak access time  of the current file.

2.87.1.15 emacsvox-dired-speak-file-modification-time

Command: emacsvox-dired-speak-file-modification-time
Speak modification time  of the current file.

2.87.1.16 emacsvox-dired-speak-file-permissions

Command: emacsvox-dired-speak-file-permissions
Speak the permissions of the current file.

2.87.1.17 emacsvox-dired-speak-file-size

Command: emacsvox-dired-speak-file-size
Speak the size of the current file.
On a directory line, run du -s on the directory to speak its size.

2.87.1.18 emacsvox-dired-speak-header-line

Command: emacsvox-dired-speak-header-line
Speak the header line of the dired buffer.

2.87.1.20 emacsvox-find-dired

Command: emacsvox-find-dired
C-e C-f
Prompt for find-dired arguments using context and completion.

2.87.1.21 emacsvox-locate-play-results-as-playlist

Command: emacsvox-locate-play-results-as-playlist (&optional shuffle)
Treat locate results as a play-list.
Optional interactive prefix arg shuffles playlist.

(fn &optional SHUFFLE)