2.104 emacsvox-empv ¶
EMPV == Emacs Front-End To mpv — the GNU media player —
Provides better Youtube integration.
This section documents Emacsvox extensions to EMPV , the Emacs
interface of choice to the GNU MPV media player.
This section should be read alongside the EMPV documentation; Install
EMPV from ELPA.
2.104.1 Interactive Commands ¶
Emacsvox adds a few convenience commands to the those provided by
package empv:
- Command
emacsvox-empv-play-url to play
a URL using MPV .
- Adds history tracking to our
EMPV commands.
- Command empv-play-last-url to play from our
EMPV history.
- Command
emacsvox-empv-play-file to play local media and
Internet streams.
2.104.2 Navigating In Time ¶
Emacsvox defines additional convenience commands to seek in streams
at different time granularities, the names are self-documenting and
bound in the empv-map.
emacsvox-empv-absolute-seek
emacsvox-empv-backward-10-minutes
emacsvox-empv-backward-10-seconds
emacsvox-empv-backward-30-minutes
emacsvox-empv-backward-5-minutes
emacsvox-empv-backward-minute
emacsvox-empv-forward-10-minutes
emacsvox-empv-forward-10-seconds
emacsvox-empv-forward-30-minutes
emacsvox-empv-forward-5-minutes
emacsvox-empv-forward-minute
emacsvox-empv-percentage-seek
emacsvox-empv-relative-seek
2.104.3 Toggling Filters ¶
Command mpv provides a number of audio filters. Emacsvox exposes a
select few for interactive use.
- Toggle active filter:
emacsvox-empv-toggle-filter
- Toggle Audio Balance:
emacsvox-empv-toggle-balance
- Clear any active filters:
emacsvox-empv-clear-filter
- Toggle our custom filter:
emacsvox-empv-toggle-custom
- Toggle left output:
emacsvox-empv-toggle-left
- Toggle right output:
emacsvox-empv-toggle-right
2.104.4 Emacsvox-Empv Commands ¶
2.104.4.1 emacsvox-empv-absolute-seek ¶
- Command: emacsvox-empv-absolute-seek (target) ¶
-
2.104.4.2 emacsvox-empv-accumulate-to-register ¶
- Command: emacsvox-empv-accumulate-to-register ¶
-
2.104.4.3 emacsvox-empv-backward-10-minutes ¶
- Command: emacsvox-empv-backward-10-minutes ¶
-
2.104.4.4 emacsvox-empv-backward-10-seconds ¶
- Command: emacsvox-empv-backward-10-seconds ¶
-
2.104.4.5 emacsvox-empv-backward-30-minutes ¶
- Command: emacsvox-empv-backward-30-minutes ¶
-
2.104.4.6 emacsvox-empv-backward-5-minutes ¶
- Command: emacsvox-empv-backward-5-minutes ¶
-
2.104.4.7 emacsvox-empv-backward-minute ¶
- Command: emacsvox-empv-backward-minute (&optional count) ¶
-
2.104.4.8 emacsvox-empv-clear-filter ¶
- Command: emacsvox-empv-clear-filter ¶
-
2.104.4.9 emacsvox-empv-current-title ¶
- Command: emacsvox-empv-current-title ¶
-
2.104.4.10 emacsvox-empv-forward-10-minutes ¶
- Command: emacsvox-empv-forward-10-minutes ¶
-
2.104.4.11 emacsvox-empv-forward-10-seconds ¶
- Command: emacsvox-empv-forward-10-seconds ¶
-
2.104.4.12 emacsvox-empv-forward-30-minutes ¶
- Command: emacsvox-empv-forward-30-minutes ¶
-
2.104.4.13 emacsvox-empv-forward-5-minutes ¶
- Command: emacsvox-empv-forward-5-minutes ¶
-
2.104.4.14 emacsvox-empv-forward-minute ¶
- Command: emacsvox-empv-forward-minute (&optional count) ¶
-
2.104.4.15 emacsvox-empv-percentage-seek ¶
- Command: emacsvox-empv-percentage-seek (target) ¶
-
2.104.4.16 emacsvox-empv-play-file ¶
- Command: emacsvox-empv-play-file (file &optional prefix) ¶
- C-e ' ¶
2.104.4.17 emacsvox-empv-play-last ¶
- Command: emacsvox-empv-play-last ¶
- C-e y l ¶
2.104.4.18 emacsvox-empv-play-url ¶
- Command: emacsvox-empv-play-url (url) ¶
- C-e y y ¶
2.104.4.19 emacsvox-empv-relative-seek ¶
- Command: emacsvox-empv-relative-seek (target) ¶
-
2.104.4.20 emacsvox-empv-time-pos ¶
- Command: emacsvox-empv-time-pos ¶
-
2.104.4.21 emacsvox-empv-toggle-balance ¶
- Command: emacsvox-empv-toggle-balance (value) ¶
-
2.104.4.22 emacsvox-empv-toggle-custom ¶
- Command: emacsvox-empv-toggle-custom ¶
-
2.104.4.23 emacsvox-empv-toggle-filter ¶
- Command: emacsvox-empv-toggle-filter (filter) ¶
-
2.104.4.24 emacsvox-empv-toggle-left ¶
- Command: emacsvox-empv-toggle-left ¶
-
2.104.4.25 emacsvox-empv-toggle-right ¶
- Command: emacsvox-empv-toggle-right ¶
-
2.104.4.26 emacsvox-empv-yt-after ¶
- Command: emacsvox-empv-yt-after ¶
-
2.104.4.27 emacsvox-empv-yt-before ¶
- Command: emacsvox-empv-yt-before ¶
-
2.104.4.28 emacsvox-empv-yt-search ¶
- Command: emacsvox-empv-yt-search (query) ¶
- C-e y s ¶
2.104.5 emacsvox-empv Options ¶
- Variable: User Option emacsvox-empv-custom-filters ¶
List of custom filters to turn on/off at one shot
The default value is suitable for classical instrumental music.
Default Value:
("extrastereo" "stereowiden=4.25:.1:735:.8" "haas")