2.123 emacsvox-filtertext

It is often useful to view the results of filtering large amounts of text.;;; Typically you do this with various combinations of grep and friends. When doing so it requires explicit effort to not destroy the original text being filtered. This module provides a textfilter utility that: A) Copies over the selected text to a special filtertext buffer B) Implements a filtertext mode for that buffer that allows easy application of filters C: Provides commands for reverting to the original unfiltered text D: Provides commands for saving results from intermediate filters.

2.123.1 Emacsvox-Filtertext Commands

2.123.1.1 emacsvox-filtertext

Command: emacsvox-filtertext (start end)
C-e ^
Copy over text in region to special filtertext buffer to  filter text.

(fn START END)

2.123.1.2 emacsvox-filtertext-mode

Command: emacsvox-filtertext-mode
Major mode for FilterText interaction.

Key             Binding
——————————————————————————-
=		keep-lines
^		flush-lines
r		emacsvox-filtertext-revert

In addition to any hooks its parent mode ‘text-mode’ might have run,
this mode runs the hook ‘emacsvox-filtertext-mode-hook’, as the final
or penultimate step during initialization.

2.123.1.3 emacsvox-filtertext-revert

Command: emacsvox-filtertext-revert
Revert to original text.