Next: emacsvox-forge, Previous: emacsvox-flyspell, Up: Emacsvox Commands And Options [Index]
Folding mode turns emacs into a folding editor. Folding mode is what I use: emacs 19 comes with similar packages, e.g. allout.el This module defines some advice forms for folding mode Think of a fold as a container.