2.132 emacsvox-gnus

This module advises gnus to speak. Updating support in 2014 (Emacsvox is nearly 20 years old) Updating in 2018 as I switch to gnus as my primary mail interface. These customizations to gnus make it convenient to listen to news: You can read news mostly by using the four arrow keys. By default all article headers are hidden, so you hear the real news.

2.132.1 Emacsvox-Gnus Commands

2.132.1.1 emacsvox-gnus-personal-gmail-last-week

Command: emacsvox-gnus-personal-gmail-last-week
Look for mail addressed personally in the last week.

2.132.1.2 emacsvox-gnus-personal-gmail-recent

Command: emacsvox-gnus-personal-gmail-recent
Look for mail addressed personally in the last day.

2.132.1.3 emacsvox-gnus-summary-catchup-quietly-and-exit

Command: emacsvox-gnus-summary-catchup-quietly-and-exit
Catch up on all articles in current group.

2.132.2 emacsvox-gnus Options

Variable: User Option emacsvox-gnus-large-article
Articles having more than
emacsvox-gnus-large-article lines will be considered to be a large article.
A large article is not spoken all at once;
instead you hear only the first screenful.

Default Value:

100

Variable: User Option emacsvox-gnus-punctuation-mode
Punctuation mode to use for Gnus buffers.
When nil, use the general punctuation policy.

Default Value:

all