2.135 emacsvox-google

There are a number of search tools that can be implemented on the Google search page — in a JS-powered browser, these show up as the Google tool-belt. This module implements a minor mode for use in Google result pages that enables these tools via single keyboard commands. Originally all options were available as tbs=p:v Now, some specialized searches, e.g. blog search are tbm=

2.135.1 Emacsvox-Google Commands

2.135.1.1 emacsvox-google-extract-from-cache

Command: emacsvox-google-extract-from-cache
Extract current  page from the Google cache.

2.135.1.2 emacsvox-google-knowledge-search

Command: emacsvox-google-knowledge-search (query &optional limit)
Perform a Google Knowledge Graph search.
Optional interactive prefix arg ‘limit’ prompts for number of
results, default is 1.

(fn QUERY &optional LIMIT)

2.135.1.3 emacsvox-google-on-this-site

Command: emacsvox-google-on-this-site
Perform a google search restricted to the current WWW site.

2.135.1.5 emacsvox-google-search-after

Command: emacsvox-google-search-after
Google from calendar — add after:date-at-point.

2.135.1.6 emacsvox-google-search-before

Command: emacsvox-google-search-before
Google from calendar — add before:date-at-point.

2.135.1.7 emacsvox-google-show-toolbelt

Command: emacsvox-google-show-toolbelt
Reload search page with toolbelt showing.

2.135.1.8 emacsvox-google-sign-in

Command: emacsvox-google-sign-in
Sign in to Google.

2.135.1.9 emacsvox-google-sign-out

Command: emacsvox-google-sign-out
Sign out to Google.

2.135.1.10 emacsvox-google-similar-to-this-page

Command: emacsvox-google-similar-to-this-page (url)
Ask Google to find documents similar to this one.

(fn URL)

2.135.1.11 emacsvox-google-toolbelt-change

Command: emacsvox-google-toolbelt-change
Command to change values in the toolbelt and execute the query.

2.135.1.12 emacsvox-google-tts-line

Command: emacsvox-google-tts-line (&optional lang)
C-. g l
C-x @ s g l
TTS line using network TTS.
Use default voice for buffer.

(fn &optional LANG)

2.135.1.13 emacsvox-google-tts-next-line

Command: emacsvox-google-tts-next-line
C-. g n
C-x @ s g n
TTS next line using network TTS.
Use default voice for buffer.

2.135.1.14 emacsvox-google-tts-previous-line

Command: emacsvox-google-tts-previous-line
C-. g p
C-x @ s g p
TTS previous line using network TTS.
Use default voice for buffer.

2.135.1.15 emacsvox-google-tts-region

Command: emacsvox-google-tts-region (start end &optional ask-lang)
C-. g r
C-x @ s g r
Speak region using Google Network TTS.

(fn START END &optional ASK-LANG)

2.135.1.16 emacsvox-google-tts-speak

Command: emacsvox-google-tts-speak (text &optional lang)
C-. g s
C-x @ s g s
Google Network TTS.
Optional interactive prefix arg ‘lang’ specifies  language identifier
which becomes buffer-local.

(fn TEXT &optional LANG)

2.135.1.17 emacsvox-google-what-is-my-ip

Command: emacsvox-google-what-is-my-ip
Show my public IP

2.135.1.19 emacsvox-google-yt-feed

Command: emacsvox-google-yt-feed (url)
C-' y
Turn YT Channel or Playlist url into an RSS feed and open it.

(fn URL)

2.135.2 emacsvox-google Options

Variable: User Option emacsvox-google-kg-key
API Key for Google Knowledge Graph.

Default Value:

nil