2.136 emacsvox-gptel

GPTEL == A simple LLM client for Emacs. gptel supports ChatGPT, Claude, Gemini, and local models via streaming responses in buffers. It provides a transient menu for model/backend selection and works in dedicated chat buffers or inline in any buffer. This module speech-enables gptel.

2.136.1 Emacsvox-Gptel Commands

2.136.1.1 emacsvox-gptel-speak-response

Command: emacsvox-gptel-speak-response
Re-read the last gptel response.