2.142 emacsvox-hide ¶
Flexible hide and show for emacsvox.
This module allows one to easily hide or expose
blocks of lines starting with a common prefix.
It is motivated by the need to flexibly hide quoted text in email
but is designed to be more general.
the prefix parsing is inspired by filladapt.el
2.142.1 Emacsvox-Hide Commands ¶
2.142.1.1 emacsvox-hide-or-expose-all-blocks ¶
- Command: emacsvox-hide-or-expose-all-blocks ¶
-
2.142.1.2 emacsvox-hide-or-expose-block ¶
- Command: emacsvox-hide-or-expose-block (&optional prefix) ¶
- C-e j ¶
2.142.1.3 emacsvox-hide-speak-block-sans-prefix ¶
- Command: emacsvox-hide-speak-block-sans-prefix ¶
- C-e C-j ¶