2.149 emacsvox-info

This module speech-enables the Emacs Info Reader.

2.149.1 Emacsvox-Info Commands

2.149.1.1 emacsvox-info-next-section

Command: emacsvox-info-next-section
Move forward to next section in this node.

2.149.1.2 emacsvox-info-previous-section

Command: emacsvox-info-previous-section
Move backward to previous section in this node.

2.149.1.3 emacsvox-info-speak-header

Command: emacsvox-info-speak-header
Speak info header line.

2.149.1.4 emacsvox-info-wizard

Command: emacsvox-info-wizard (node-spec)
C-h TAB
<f1> TAB
<help> TAB
Read a node spec from the minibuffer and launch
Info-goto-node.
See documentation for command ‘Info-goto-node’ for details on
node-spec.

(fn NODE-SPEC)

2.149.2 emacsvox-info Options

Variable: User Option emacsvox-info-select-node-speak-chunk
Specifies how much of the selected node gets spoken.
Possible values are:
screenfull  -- speak the displayed screen
node -- speak the entire node.

Default Value:

screenfull