2.150 emacsvox-ispell

This module speech enables ispell. Implementation note: This is hard because of how ispell.el is written Namely, all of the work is done by one huge hairy function. This makes advising it hard. The ispell commands work well with Emacsvox as long as the list of correction choices are few. For interactively moving through corrections, install package flyspell-correct from MELPA (package-install "flyspell-correct") Then use M-x flyspell-mode. Package flyspell is speech-enabled by Emacsvox module emacsvox-flyspell. That module uses standard completion by default, so Vertico or another active completion frontend presents correction choices. IDO, Popup, and Helm remain available as explicit alternatives.

2.150.1 emacsvox-ispell Options

Variable: User Option emacsvox-ispell-max-choices
Maximum number of correction choices Emacsvox will speak.
When Ispell returns more choices, Emacsvox speaks this many of the
highest-ranked corrections and announces the total.

Default Value:

8