2.177 emacsvox-org

Speech-enable org — Org allows you to keep organized notes and todo lists. Homepage: http://www.astro.uva.nl/~dominik/Tools/org/ or http://orgmode.org/

2.177.1 Emacsvox-Org Commands

2.177.1.1 emacsvox-org-amarks-play

Command: emacsvox-org-amarks-play
Loop through and play list of Amarks from org buffer.
Hit C-g to break out of the loop.
Press ‘y’ to play to next amark.

2.177.1.3 emacsvox-org-popup-input

Command: emacsvox-org-popup-input
Pops up an org input area.

2.177.1.4 emacsvox-org-popup-input-buffer

Command: emacsvox-org-popup-input-buffer (mode)
Provide an input buffer in a specified mode.

(fn MODE)

2.177.1.5 emacsvox-org-speak-item

Command: emacsvox-org-speak-item
Speak the current Org item through one semantic presentation.

2.177.1.6 emacsvox-org-table-speak-both-headers-and-element

Command: emacsvox-org-table-speak-both-headers-and-element
Speak both headers and the current Org table cell.

2.177.1.7 emacsvox-org-table-speak-column-header

Command: emacsvox-org-table-speak-column-header
Speak the current Org table column header.

2.177.1.8 emacsvox-org-table-speak-column-header-and-element

Command: emacsvox-org-table-speak-column-header-and-element
Speak the column header and current Org table cell.

2.177.1.9 emacsvox-org-table-speak-coordinates

Command: emacsvox-org-table-speak-coordinates
Speak the current Org table coordinates.

2.177.1.10 emacsvox-org-table-speak-current-element

Command: emacsvox-org-table-speak-current-element
Speak the current Org table cell.

2.177.1.11 emacsvox-org-table-speak-row-header

Command: emacsvox-org-table-speak-row-header
Speak the current Org table row header.

2.177.1.12 emacsvox-org-table-speak-row-header-and-element

Command: emacsvox-org-table-speak-row-header-and-element
Speak the row header and current Org table cell.

2.177.2 emacsvox-org Options

Variable: User Option emacsvox-org-hotlist
Emacsvox org hotlist location.

Default Value:

"~/.org/hotlist.org"

Variable: User Option emacsvox-org-table-after-movement-function
The function to call after moving in a table

Default Value:

emacsvox-org-table-speak-current-element