2.189 emacsvox-pronounce

This module implements user customizable pronunciation dictionaries for emacsvox. Custom pronunciations can be defined per file, per directory and/or per major mode. Emacsvox maintains a persistent user dictionary upon request and loads these in new emacsvox sessions. This module implements the user interface to the custom dictionary as well as providing the internal API used by the rest of emacsvox in using the dictionary.

2.189.1 Algorithm:

The persistent dictionary is a hash table where the hash keys are filenames, directory names, or major-mode names. The hash values are association lists defining the dictionary. Users of this module can retrieve a dictionary made up of all applicable association lists for a given file.

2.189.2 Emacsvox-Pronounce Commands

2.189.2.1 emacsvox-pronounce-clear

Command: emacsvox-pronounce-clear
Clear all current pronunciation dictionaries.

2.189.2.2 emacsvox-pronounce-define-pronunciation

Command: emacsvox-pronounce-define-pronunciation
Interactively define entries in the pronunciation dictionaries.
Default term to define is delimited by region.
First loads any persistent dictionaries if not already loaded.

2.189.2.3 emacsvox-pronounce-define-template-pronunciation

Command: emacsvox-pronounce-define-template-pronunciation
Interactively define template entries in the pronunciation dictionaries.
Default term to define is delimited by region.
First loads any persistent dictionaries if not already loaded.

2.189.2.4 emacsvox-pronounce-dispatch

Command: emacsvox-pronounce-dispatch
C-e M-d
Pronounce Frontend

2.189.2.5 emacsvox-pronounce-edit-pronunciations

Command: emacsvox-pronounce-edit-pronunciations (key)
Prompt for and launch a pronunciation editor on the
specified pronunciation dictionary key.

(fn KEY)

2.189.2.6 emacsvox-pronounce-load-dictionaries

Command: emacsvox-pronounce-load-dictionaries (&optional filename)
Load pronunciation dictionaries.
Optional argument FILENAME specifies the dictionary file,
Default is emacsvox-pronounce-dictionaries-file.

(fn &optional FILENAME)

2.189.2.7 emacsvox-pronounce-merge-dictionaries

Command: emacsvox-pronounce-merge-dictionaries (from into)
Merge dic ‘from’ into dict ‘into’

(fn FROM INTO)

2.189.2.8 emacsvox-pronounce-refresh-pronunciations

Command: emacsvox-pronounce-refresh-pronunciations
Refresh pronunciation table for current buffer.

2.189.2.9 emacsvox-pronounce-save-dictionaries

Command: emacsvox-pronounce-save-dictionaries
Saves  pronunciation dictionaries.

2.189.2.10 emacsvox-pronounce-toggle-dictionaries

Command: emacsvox-pronounce-toggle-dictionaries (&optional state)
Toggle  pronunciation dictionaries.

(fn &optional STATE)

2.189.2.11 emacsvox-pronounce-toggle-voice

Command: emacsvox-pronounce-toggle-voice
Toggle use of pronunciation personality.

2.189.3 emacsvox-pronounce Options

Variable: User Option emacsvox-pronounce-dictionaries-file
File that holds  emacsvox pronunciations.

Default Value:

"~/.emacsvox/.dictionary"

Variable: User Option emacsvox-pronounce-internet-smileys-pronunciations
Smileys

Default Value:

((":-)" . " smile ")
 (";)" . " half-wink ")
 (":)" . " grin ")
 (":-(" . " frown ")
 (":(" . " sigh ")
 (":-I" . " shrug ")
 (":->" . " sarcastic smile ")
 (">:->" . " devillish smile ")
 (">;->" . " lewd smile ")
 (";-)" . " wink "))

Variable: User Option emacsvox-pronounce-xml-ns
Namespace URIs.

Default Value:

(("http://www.w3.org/2005/Atom" . " atom ")
 ("http://www.w3.org/1999/02/22-rdf-syntax-ns#" . "RDF Syntax")
 ("http://www.w3.org/2002/06/xhtml2" . " xhtml2 ")
 ("http://www.w3.org/2003/XInclude" . "XInclude")
 ("http://www.w3.org/1999/XSL/Transform" . " XSLT ")
 ("http://www.w3.org/2002/xforms" . " XForms ")
 ("http://www.w3.org/2001/xml-events" . " XEvents ")
 ("http://www.w3.org/2001/vxml" . " vxml ")
 ("http://www.w3.org/2001/XMLSchema-instance" . " XSI ")
 ("http://www.w3.org/2001/XMLSchema" . " XSD ")
 ("http://www.w3.org/1999/xhtml" . " xhtml ")
 ("http://purl.org/dc/elements/1.1/" . "DC")
 ("http://search.yahoo.com/mrss/" . "media"))