Auditory interface to solitaire
Present first-class tones for each cell in the current column.
Present first-class tones for each cell in the current row.
Present the current cell coordinates in one native transaction. Optional ICON precedes the content. OCCASION defaults to ‘inspection’, and EVENT records an optional semantic event. (fn &optional ICON OCCASION EVENT)