2.212 emacsvox-sounds ¶
This module provides the interface for generating auditory icons.
It also defines sound themes for auditory icons.
2.212.1 Design goal: ¶
- Auditory icons should be used to
provide additional feedback, not as a gimmick.
- The Emacsvox interface
should be usable at all times with the icons turned off.
- Command
emacsvox-toggle-icons toggles the
use of auditory icons. This flag is buffer-local; use an
interactive prefix argosy C-u to toggle auditory icons on/off
globally.
- Use
setq-default emacsvox-use-icons nil) to turn
auditory icons off at startup; default is to use auditory icons globally.
- General principle for using auditory icons:
- Convey information about events taking place in parallel.
- For instance, if making a selection automatically moves the current
focus to the next choice, We speak the next choice, while
indicating the fact that something was selected with an auditory
icon.
- Speed up task completion — auditory icons take less time than
the accompanying spoken feedback.
- This module provides a mapping between names in the elisp
world and actual sound files.
- icon names are symbols,
sound files are strings — fully-qualified file-names.
- Modules that use auditory icons
use icon names and not actual file names.
- Icons are played either using a local player, or by sending
appropriate commands to the speech server (local or cloud).
- This is determined by the value of
emacsvox-play-program.
- As of
Emacsvox 13.0, this module defines a sound-pack architecture for
auditory icons. Bundled packs live below sounds/packs/; personal
packs live below ~/.emacsvox/sounds/packs/ by default.
- The bundled packs are
chimes and 3d. Additional
pack directories containing button.ogg, or a data-only
emacsvox-sound-pack.el manifest, are discovered dynamically.
- Contrast this with
prompts — they dont belong to any theme.
2.212.2 Designing Auditory Icons ¶
Here are some notes on what I have learnt while designing and using
auditory icons over the years:
- Auditory icons should be short — use command
soxi or
; in a dired buffer to see duration of a sound file. Use
the bundled themes as a guide.
- Sounds have many properties, eg: duration, gain, pitch, at
the basic level.
- Even more important is the nature of the sound and what it sounds
like in the context of the overall speech output where that sound is used.
- This is why the gain of icons should never be normalized in
my view— tuning icons is as complex as picking
colors from a color palette.
- The included themes have been optimized over years of use and
are primarily tuned for using with headphones.
If emacsvox-play-program is set to nil,
we serve icons, otherwise play
them using a local player.
2.212.3 Emacsvox-Sounds Commands ¶
2.212.3.1 emacsvox-sounds-select-theme ¶
- Command: emacsvox-sounds-select-theme (&optional theme) ¶
- C-e ) ¶
2.212.3.2 emacsvox-toggle-icons ¶
- Command: emacsvox-toggle-icons (&optional prefix) ¶
- C-e C-a ¶
2.212.4 emacsvox-sounds Options ¶
- Variable: User Option emacsvox-play-program ¶
Play program.
Pulse: For systems running Pipewire or Pulseaudio.
sox-play: For systems using SoX as the local player.
None: For systems that rely on the speech server playing the icon.
Default Value:
"/usr/bin/pactl"