2.214 emacsvox-speedbar

This module advises speedbar.el for use with Emacs. The latest speedbar can be obtained from ftp://ftp.ultranet.com/pub/zappo/ This module ensures that speedbar works smoothly outside a windowing system in addition to speech enabling all interactive commands. Emacsvox also adds an Emacsvox environment specific entry point to speedbar –emacsvox-speedbar-goto-speedbar– and binds this

2.214.1 Emacsvox-Speedbar Commands

2.214.1.1 emacsvox-speedbar-click

Command: emacsvox-speedbar-click
Does the equivalent of the mouse click from the keyboard

2.214.1.2 emacsvox-speedbar-goto-speedbar

Command: emacsvox-speedbar-goto-speedbar
Switch to the speedbar