TRANSIENT == Transient commands — used by magit and friends. This module speech-enables transient.
Package Transient is similar to package Hydra in the sense that it can be used to create a sequence of chained/hierarchical commands that are invoked via a sequence of keys. It is used by Magit for dispatching to the various Git commands. Speech-enabling package Transient results in the various interactive commands producing auditory feedback. Transient shows an ephemeral window with the currently available commands, Emacsvox speech-enables transient–show to cache that content so it can be browsed if desired.
Finally, this module defines a new minor mode called transient-emacsvox that enables interactive browsing of the contents displayed temporarily. Note that without this functionality, learning complex packages like Magit would be difficult because the list of available commands can be very long.
I use the following customizations via .custom, adjust to taste, but use these only after reading the transient info documentations.
this pops up the transient buffer after a short delay and lets you move through the buttons with the up/down arrows.
When executing a command defined via Transient — e.g. command
Magit-dispatch and friends,
? twice to suspend the transient — this calls
2transient-suspend. Emacsvox now
displays a *transient-emacsvox* buffer that displays the contents of the
most recently displayed transient choices. Pressing r resumes
the transient; Pressing C-q quits the transient.
emacsvox integration with Transient. In addition to any hooks its parent mode ‘special-mode’ might have run, this mode runs the hook ‘emacsvox-transient-mode-hook’, as the final or penultimate step during initialization.