2.234 emacsvox-vdiff

VDIFF == vimdiff Installable from melpa, vdiff enables synchronized movement through diff buffers without resorting to an extra control-panel as is the case with ediff. In addition to speech-enabling interactive commands and setting up face->voice mappings, this module provides commands that speak the current hunk. These are bound in vdiff-mode-prefix-map.

2.234.1 Emacsvox-Vdiff Commands

2.234.1.1 emacsvox-vdiff-speak-other-hunk

Command: emacsvox-vdiff-speak-other-hunk
Speak corresponding hunk from other buffer.

2.234.1.2 emacsvox-vdiff-speak-other-line

Command: emacsvox-vdiff-speak-other-line
Speak corresponding line from other buffer.

2.234.1.3 emacsvox-vdiff-speak-this-hunk

Command: emacsvox-vdiff-speak-this-hunk
Speak VDiff hunk under point.