2.235 emacsvox-version

Read the canonical release identifier from the repository-level VERSION file. Reading it when this module loads keeps source and byte-code users on the same value without generating a second version source.