2.241 emacsvox-websearch

This module provides utility functions for searching the WWW

2.241.1 Emacsvox-Websearch Commands

2.241.1.1 emacsvox-websearch-amazon-search

Command: emacsvox-websearch-amazon-search
C-e ? C-a
C-e / C-a
Amazon search.

2.241.1.2 emacsvox-websearch-ask-jeeves

Command: emacsvox-websearch-ask-jeeves (query)
C-e ? j
C-e / j
Ask Jeeves for the answer.

(fn QUERY)

2.241.1.3 emacsvox-websearch-foldoc-search

Command: emacsvox-websearch-foldoc-search (query)
C-e ? f
C-e / f
Perform a FolDoc search.

(fn QUERY)

2.241.1.4 emacsvox-websearch-google

Command: emacsvox-websearch-google (query &optional flag)
C-e RET
C-e ? g
C-e / g
Perform a Google search.  First optional interactive prefix arg
‘flag’ prompts for additional search options. Second interactive
prefix arg is equivalent to hitting the I’m Feeling Lucky button on Google.

(fn QUERY &optional FLAG)

2.241.1.5 emacsvox-websearch-google-feeling-lucky

Command: emacsvox-websearch-google-feeling-lucky (query)
C-e ? SPC
C-e / SPC
Do a I’m Feeling Lucky Google search.

(fn QUERY)

2.241.1.6 emacsvox-websearch-google-lite

Command: emacsvox-websearch-google-lite (query &optional options)
C-e ? a
C-e / a
Use Google Lite.
Optional prefix arg prompts for toolbelt options.

(fn QUERY &optional OPTIONS)

2.241.1.7 emacsvox-websearch-google-news

Command: emacsvox-websearch-google-news
C-e ? n
C-e / n
Invoke Google News url template.

2.241.1.8 emacsvox-websearch-google-search-in-date-range

Command: emacsvox-websearch-google-search-in-date-range
Use this from inside the calendar to do Google date-range searches.

2.241.1.9 emacsvox-websearch-google-with-toolbelt

Command: emacsvox-websearch-google-with-toolbelt (query)
C-e ? i
C-e / i
Launch Google search with toolbelt.

(fn QUERY)

2.241.1.10 emacsvox-websearch-gutenberg

Command: emacsvox-websearch-gutenberg (type query)
C-e ? G
C-e / G
Perform an Gutenberg search

(fn TYPE QUERY)

2.241.1.11 emacsvox-websearch-help

Command: emacsvox-websearch-help
C-e ? ?
C-e / ?
Displays key mapping used by Emacsvox Websearch.

2.241.1.12 emacsvox-websearch-web-filter-google

Command: emacsvox-websearch-web-filter-google (query &optional options)
C-e ? u
C-e / u
Use Google Lite with Web filter.
Optional prefix arg prompts for toolbelt options.

(fn QUERY &optional OPTIONS)

2.241.1.13 emacsvox-websearch-wikipedia-search

Command: emacsvox-websearch-wikipedia-search (query)
C-e ? w
C-e / w
Search Wikipedia using Google.
Use URL Template ‘wikipedia at point’ to advantage in the results buffer.

(fn QUERY)

2.241.1.14 emacsvox-websearch-youtube-search

Command: emacsvox-websearch-youtube-search (query)
C-e ? y
C-e / y
YouTube search.

(fn QUERY)