2.242 emacsvox-webspace

WEBSPACE == Smart Web Gadgets For The Emacsvox Desktop

2.242.1 Emacsvox-Webspace Commands

2.242.1.1 emacsvox-webspace-feed-reader

Command: emacsvox-webspace-feed-reader (&optional refresh)
C-. R
C-x @ s R
Display Feed Reader Feed list in a WebSpace buffer.
Optional interactive prefix arg forces a refresh.

(fn &optional REFRESH)

2.242.1.2 emacsvox-webspace-filter

Command: emacsvox-webspace-filter
Open headline at point and filter for content.

2.242.1.3 emacsvox-webspace-headlines

Command: emacsvox-webspace-headlines
Startup Headlines ticker using RSS/Atom  feeds.

2.242.1.4 emacsvox-webspace-headlines-browse

Command: emacsvox-webspace-headlines-browse
Display buffer of browsable headlines.

2.242.1.5 emacsvox-webspace-headlines-update

Command: emacsvox-webspace-headlines-update
Setup news updates.
Updated headlines found in emacsvox-webspace-headlines.

2.242.1.6 emacsvox-webspace-mode

Command: emacsvox-webspace-mode
Major mode for Webspace interaction.

Key             Binding
——————————————————————————-
TAB		forward-button
’		emacsvox-speak-rest-of-buffer
.		emacsvox-webspace-filter
/		search-forward
<		beginning-of-buffer
>		end-of-buffer
?		search-backward
b		backward-button
f		forward-button
n		forward-button
p		backward-button
q		bury-buffer
y		emacsvox-webspace-yank-link
<backtab>	backward-button

C-M-i		backward-button

In addition to any hooks its parent mode ‘special-mode’ might have
run, this mode runs the hook ‘emacsvox-webspace-mode-hook’, as the
final or penultimate step during initialization.

2.242.1.7 emacsvox-webspace-open

Command: emacsvox-webspace-open
Open headline at point by following its link property.

2.242.2 emacsvox-webspace Options

Variable: User Option emacsvox-webspace-feeds
Feeds to use in Headline Ticker.

Default Value:

nil