2.243 emacsvox-which-key

Which-Key displays available keybindings in a popup after pressing a prefix key. This module speech-enables Which-Key to provide auditory feedback for available bindings, supporting navigation through pages and speaking the current binding options.

2.243.1 Emacsvox-Which-Key Commands

2.243.1.1 emacsvox-which-key-speak

Command: emacsvox-which-key-speak
Speak the current or last which-key popup content.

2.243.1.2 emacsvox-which-key-toggle-auto-speak

Command: emacsvox-which-key-toggle-auto-speak
Toggle automatic speaking of which-key popups.