Next: emacsvox-windmove, Previous: emacsvox-which-key, Up: Emacsvox Commands And Options [Index]
This module implements the necessary extensions to provide talking widgets.
required modules
Allows you to browse a widget
Speak help for widget under point.
Summarize parent of widget at point.
Summarize a widget if any under point. Optional interactive prefix specifies how many levels to go up from current widget before summarizing. (fn &optional LEVEL)
Sets widget at ‘pos’ by invoking its prompter. (fn POS)