2.251 emacsvox-xslt

libxml and libxsl are XML libraries for GNOME. xsltproc is a xslt processor using libxsl this module defines routines for applying xsl transformations using xsltproc

2.251.1 Emacsvox-Xslt Commands

2.251.1.1 emacsvox-xslt-view

Command: emacsvox-xslt-view (style url)
Browse URL with specified XSL style.

(fn STYLE URL)

2.251.1.2 emacsvox-xslt-view-atom-file

Command: emacsvox-xslt-view-atom-file (file)
C-e v a
View Atom file.

(fn FILE)

2.251.1.3 emacsvox-xslt-view-file

Command: emacsvox-xslt-view-file (style file)
C-e v x
Transform ‘file’ using ‘style’ and preview via browse-url.

(fn STYLE FILE)

2.251.1.4 emacsvox-xslt-view-region

Command: emacsvox-xslt-view-region (style start end &optional unescape-charent)
Browse XML region with specified XSL style.

(fn STYLE START END &optional UNESCAPE-CHARENT)

2.251.1.5 emacsvox-xslt-view-rss-file

Command: emacsvox-xslt-view-rss-file (file)
C-e v r
View RSS file.

(fn FILE)

2.251.1.6 emacsvox-xslt-view-xml

Command: emacsvox-xslt-view-xml (style url &optional unescape-charent)
Browse XML URL with specified XSL style.

(fn STYLE URL &optional UNESCAPE-CHARENT)