Implements the Google Maps API
Google Maps Interaction. This function has :after advice: ‘emacsvox–advice-gmaps-after’. (fn)
Biking directions from Google Maps. This function has :after advice: ‘emacsvox–advice-gmaps-bicycling-directions-after’. (fn ORIGIN DESTINATION)
Display directions obtained from Google Maps. (fn ORIGIN DESTINATION MODE)
Driving directions from Google Maps. This function has :after advice: ‘emacsvox–advice-gmaps-driving-directions-after’. (fn ORIGIN DESTINATION)
A Google Maps front-end for the Emacsvox desktop. In addition to any hooks its parent mode ‘special-mode’ might have run, this mode runs the hook ‘gmaps-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- TAB forward-button SPC gmaps-place-details [ backward-page ] forward-page b gmaps-bicycling-directions c gmaps-set-current-location d gmaps-driving-directions f gmaps-set-current-filter n gmaps-places-nearby r gmaps-set-current-radius s gmaps-places-search t gmaps-transit-directions w gmaps-walking-directions M-i backward-button
Display details for place at point. Insert reviews if already displaying details. This function has :around advice: ‘emacsvox–advice-gmaps-place-details-around’. (fn)
Display reviews for place at point. Place details need to have been expanded first.
Find places near current location. Uses default radius. optional interactive prefix arg clears any active filters. This function has :after advice: ‘emacsvox–advice-gmaps-places-nearby-after’. (fn &optional CLEAR-FILTER)
Perform a places search. Use this only if you dont know the locality of the place you’re looking for. Optional prefix arg clears any active filters. This function has :after advice: ‘emacsvox–advice-gmaps-places-search-after’. (fn QUERY &optional CLEAR-FILTER)
Set up filter in current buffer. Optional interactive prefix arg prompts for all filter fields. (fn &optional ALL)
Set current location. This function has :after advice: ‘emacsvox–advice-gmaps-set-current-location-after’. (fn ADDRESS)
Set current radius This function has :after advice: ‘emacsvox–advice-gmaps-set-current-radius-after’. (fn RADIUS)