2.260 light ¶
Provide an emacs front-end to light.
This is a tool that controls the brightness on laptops.
To install light,
sudo apt-get install light
Install light setuid (sudo chmod u+s /usr/bin/light)
This module is most easily used in conjunction with hydra:
M-x package-install hydra
2.260.1 Light Commands ¶
2.260.1.1 light-black ¶
- Command: light-black ¶
-
2.260.1.2 light-decrement ¶
- Command: light-decrement ¶
-
2.260.1.3 light-get ¶
- Command: light-get ¶
-
2.260.1.4 light-increment ¶
- Command: light-increment ¶
-
2.260.1.5 light-set ¶
- Command: light-set (brightness) ¶
-
2.260.1.6 light-white ¶
- Command: light-white ¶
-