2.265 pip

Piper TTS is an Open Source neural-net TTS engine. This module exposes Piper TTS to Emacs.

  1. Sandbox for https://github.com/OHF-Voice/piper1-gpl
  2. Install piper-tts in a virtual environment whose bin directory is on Emacs’s PATH.
  3. Set location of voice data in pip-data-dir. Default is ~/.local/share/voices-piper
  4. Use that environment’s Python to run -m piper.download_voices. Download a voice with its --data-dir option set to pip-data-dir.
  5. M-x pip-speak to speak.
  6. At present piper is not suitable for use as a primary TTS engine for Emacsvox through this experimental per-request wrapper, given its model-load latency and fixed 22,050 Hz raw-output assumption.
  7. However it might be interesting to use it for lower-priority speech where quality trumps latency.

2.265.1 Pip Commands

2.265.1.1 pip-device-select

Command: pip-device-select (device)
Select default from available choices.
Restarts piper pipeline if already running.

(fn DEVICE)

2.265.1.2 pip-model-select

Command: pip-model-select (voice)
Select default from available choices.
Restarts piper pipeline if already running.

(fn VOICE)

2.265.1.3 pip-speak

Command: pip-speak (text)
Speak text

(fn TEXT)

2.265.1.4 pip-start

Command: pip-start
Start the Piper process

2.265.1.5 pip-stop

Command: pip-stop
Stop Piper TTS