Next: soundscape, Previous: pip, Up: Emacsvox Commands And Options [Index]
This module defines the various voices used in voice-lock mode. Module Plain is suitable for a device for which you haven’t yet implemented appropriate voice-locking controls
required modules