Soundscapes https://en.wikipedia.org/wiki/Soundscape
define an acoustic environment.
Boodler at http://boodler.org is a
Python-based SoundScape generator.
To use this module, first install boodler.
Then install the soundscape packages (*.boop) files available
at http://boodler.org/lib.
Make sure boodler works and produces audio in your environment.
finally install the Boodler packages from
emacsvox/scapes from the Emacsvox GitHub repository by running
cd emacsvox/scapes; make
When boodler is set up and all packages installed, copy file emacsvox/scapes/soundscapes to ~/.boodler/Collection. The above file lists all installed SoundScapes. Directory emacsvox/scapes also contains additional Boodler Agents and SoundScapes that I have created for use with Emacsvox.
Module soundscape.el defines Emacs conveniences for running Soundscapes. Main Entry Points:
When automatic Soundscapes are enabled, SoundScapes are started and stopped based on the current major mode. Active Soundscape are displayed as part of the minor-mode-alist. Command emacsvox-speak-minor-mode-line can be used to have this spoken.
Thus, SoundScapes can be thought of as reflecting the
mood of the current mode.
This package defines a single soundscape-default-theme
that is loaded using (soundscape-load soundscape-default-theme).
Emacs modes that provide similar functionality e.g.,
communication == email, IM, ... map to the same mood.
Start a Soundscape listener. Listener is loaded with all Soundscapes defined in ‘soundscape-default-theme’ . Optional interactive prefix arg restarts the listener. (fn &optional RESTART)
Activate scapes named ‘names’ — a list of strings. (fn NAMES)
Soundscape data directory.
Default Value:
"~/.boodler/Collection"
Alsa sound device to use for soundscapes.
Default Value:
"default"
User customizable options list passed to boodler. Defaults specify alsa as the output and set master volume
Default Value:
("-o" "pulse" "-m" "0.15")