2.268 sox

This module defines a convenient speech-enabled interface for editing mp3 and wav files using SoX.

Launching M-x sox creates a special interaction buffer that provides single keystroke commands for editing and applying effects to a selected sound file. For adding mp3 support to sox, do

sudo apt-get libsox-fmt-mp3 install

This module provides support for ladspa effects using module ladspa.el. To use ladspa effects with SoX, you need a relatively new build of Sox; The stock SoX that is package for Debian/Ubuntu does not always work. This module can be used independent of Emacsvox.

2.268.1 Sox Commands

2.268.1.1 sox-add-effect

Command: sox-add-effect (name)
Adds  effect at the end of the effect list

(fn NAME)

2.268.1.2 sox-delete-effect-at-point

Command: sox-delete-effect-at-point
Delete effect at point.

This function has :after advice: ‘emacsvox–advice-sox-delete-effect-at-point-after’.

(fn)

2.268.1.3 sox-edit-effect-at-point

Command: sox-edit-effect-at-point
Edit effect at point.

2.268.1.4 sox-mode

Command: sox-mode
An audio workbench for the Emacsvox desktop.

In addition to any hooks its parent mode ‘special-mode’ might have
run, this mode runs the hook ‘sox-mode-hook’, as the final or
penultimate step during initialization.

2.268.1.5 sox-open-file

Command: sox-open-file (snd-file)
Open specified snd-file on the Audio Workbench.

This function has :after advice: ‘emacsvox–advice-sox-open-file-after’.

(fn SND-FILE)

2.268.1.6 sox-play

Command: sox-play
Play sound .

2.268.1.7 sox-refresh

Command: sox-refresh
Redraw Audio Workbench.

This function has :after advice: ‘emacsvox–advice-sox-refresh-after’.

(fn)

2.268.1.8 sox-save

Command: sox-save (save-file)
Save context to  file after prompting.

(fn SAVE-FILE)

2.268.1.9 sox-set-effect

Command: sox-set-effect (name)
Set effect.

(fn NAME)

2.268.1.10 sox-show-timestamp

Command: sox-show-timestamp
Show timestamp   in stream.

2.268.1.11 sox-stop

Command: sox-stop
Stop currently playing  sound from current context.