2.275 xbacklight ¶
Provide an emacs front-end to xbacklight.
This is a tool that controls the brightness on laptops.
To install xbacklight,
sudo apt-get install xbacklight
This module is most easily used in conjunction with hydra:
M-x package-install hydra
2.275.1 Xbacklight Commands ¶
2.275.1.1 xbacklight-black ¶
- Command: xbacklight-black ¶
-
2.275.1.2 xbacklight-decrement ¶
- Command: xbacklight-decrement ¶
-
2.275.1.3 xbacklight-get ¶
- Command: xbacklight-get ¶
-
2.275.1.4 xbacklight-increment ¶
- Command: xbacklight-increment ¶
-
2.275.1.5 xbacklight-set ¶
- Command: xbacklight-set (brightness) ¶
-
2.275.1.6 xbacklight-white ¶
- Command: xbacklight-white ¶
-