This chapter documents the various Emacsvox modules and is auto-generated from the Emacsvox source code. It is meant to be a complete reference to the emacsvox implementation while also providing high-level usage summaries of some of the larger Emacsvox modules.
Each section provides a high-level overview of that module, followed by detailed description of the commands and options defined in that module.
Emacsvox modules can be classified as follows:
espeak-voices and dectalk-voices.
emacsvox-speak, emacsvox-keymap, voice-lock and
emacsvox-advice.
emacsvox-<packagename>.
The first two of the above are mostly of interest when extending Emacsvox, or to learn how things are implemented. The third category is useful in understanding how emacsvox works with a given package; thus, when learning to use the Emacs Web Browser (EWW), read the See (emacs)EWW documentation, then See emacsvox-eww.
This chapter documents a total of 1467 commands and 191 options.