Diagnose the running aural installation and configuration without starting a speech server or changing presentation state. Safe, deterministic repairs are explicit commands from the spoken report.
Open the spoken Aural Doctor and announce its overall result.
Display and speak Aural Doctor help.
Spoken diagnostics for aural presentation. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-doctor-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- ? emacsvox-aural-doctor-help h emacsvox-aural r emacsvox-aural-doctor-repair-current
Move to and speak the next diagnostic finding.
Move right and speak the next diagnostic column.
Move to and speak the previous diagnostic finding.
Move left and speak the previous diagnostic column.
Rerun diagnostics, preserving row ID and the current column. (fn &optional ID)
Refresh dynamically discovered and registered sound packs.
Reload the validated personal aural data file.
Run the deterministic repair offered by the finding at point.
Restore the documented aural home and point-explanation bindings.