Retained and simulated presentation explanations, spoken and visual reports, spatial capability inspection, concise descriptions, and training mode.
Describe current spatial backends and user policy.
Explain exact queued RECORD or simulate FACTS in CONTEXT. Interactively, use the last queued presentation for the source buffer when available. With a prefix argument, deliberately simulate an occasion chosen by the user. When no queued record is available, infer the occasion that produces the most useful simulation. The visual and spoken explanations always identify whether they describe queued output or a simulation. (fn &optional FACTS CONTEXT RECORD)
Speak concise semantics after each normal aural presentation. This is a global minor mode. If called interactively, toggle the ‘Emacsvox-Aural-Training mode’ mode. If the prefix argument is positive, enable the mode, and if it is zero or negative, disable the mode. If called from Lisp, toggle the mode if ARG is ‘toggle’. Enable the mode if ARG is nil, omitted, or is a positive number. Disable the mode if ARG is a negative number. To check whether the minor mode is enabled in the current buffer, evaluate ‘(default-value ’emacsvox-aural-training-mode)’. The mode’s hook is called both when the mode is enabled and when it is disabled. (fn &optional ARG)
Describe current spatial backends and user policy.
Explain exact queued RECORD or simulate FACTS in CONTEXT. Interactively, use the last queued presentation for the source buffer when available. With a prefix argument, deliberately simulate an occasion chosen by the user. When no queued record is available, infer the occasion that produces the most useful simulation. The visual and spoken explanations always identify whether they describe queued output or a simulation. (fn &optional FACTS CONTEXT RECORD)
Non-nil if Emacsvox-Aural-Training mode is enabled. See the ‘emacsvox-aural-training-mode’ command for a description of this minor mode. Setting this variable directly does not take effect; either customize it (see the info node ‘Easy Customization’) or call the function ‘emacsvox-aural-training-mode’.
Default Value:
nil
Hook run after entering or leaving ‘emacsvox-aural-training-mode’. No problems result if this variable is not bound. ‘add-hook’ automatically binds it. (This is true for all hook variables.)
Default Value:
nil
Palette-aware voice used for semantic training explanations.
Default Value:
annotate