Status and routing home for aural presentation discovery, management, diagnosis, and contextual remapping.
Perform the primary operation for the aural home row at point.
Explain presentation at point in the remembered source buffer.
Display and speak aural home commands and discovery guidance.
Spoken home mode for aural presentation discovery and interaction. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-home-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-home-activate ? emacsvox-aural-home-help D emacsvox-aural-doctor H emacsvox-aural-home-recent-feedback O emacsvox-aural-home-overrides P emacsvox-aural-home-profiles R emacsvox-aural-home-remap-earcon V emacsvox-aural-home-voice-palettes W emacsvox-aural-home-voice-workbench r emacsvox-aural-home-remap-voice x emacsvox-aural-home-explain
Move to and speak the next aural home row.
Move right and speak the next aural home column.
Open unified presentation overrides from Aural Home.
Move to and speak the previous aural home row.
Move left and speak the previous aural home column.
Open the complete presentation-profile manager.
Open bounded retained presentations from Aural Home.
Refresh aural home status, preserving row ID and the current column. (fn &optional ID)
Prepare an earcon override for the remembered source item.
Prepare a voice override for the remembered source item.
Speak the complete aural home row at point.
Speak the current aural home column title and value.