Semantic selection, representative facts, reference discovery, and the accessible browser for the registered aural vocabulary.
Describe registered SEMANTIC and presentation data that uses it. (fn &optional SEMANTIC)
Open the accessible list of registered semantic vocabulary.
Display and speak semantic-list help.
Major mode for browsing registered aural semantics. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-semantics-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-describe-aural-semantic ? emacsvox-aural-semantics-help h emacsvox-aural
Move to and speak the next semantic.
Move right and speak the next semantic column title and value.
Move to and speak the previous semantic.
Move left and speak the previous semantic column title and value.
Refresh the semantic list, preserving SEMANTIC and the current column. (fn &optional SEMANTIC)
Speak a concise description of the semantic at point.
Speak the current semantic column title and value.