Accessible sound-pack and cue browsers. Users can inspect native, inherited, fallback, and missing assets; audition concrete cues; activate packs; validate coverage; open directories; and edit safe discovered-pack manifests without editing raw Lisp.
Open the spoken cue browser for PACK or the sound pack at point. (fn &optional PACK)
Open the spoken sound-pack manager, selecting PACK when supplied. (fn &optional PACK)
Audition the concrete cue at point.
Display and speak sound-pack cue-browser help.
Spoken browser for sound-pack cue intent and concrete provenance. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-sound-pack-cues-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-sound-pack-cues-audition ? emacsvox-aural-sound-pack-cues-help P emacsvox-aural-sound-pack-cues-audition h emacsvox-aural o emacsvox-aural-sound-packs-open-directory s emacsvox-aural-list-sound-packs v emacsvox-aural-sound-pack-cues-show-validation
Move to and speak the next cue.
Move right and speak the next cue column.
Move to and speak the previous cue.
Move left and speak the previous cue column.
Refresh the cue browser, preserving CUE and the current column. (fn &optional CUE)
Display and speak validation for the cue browser’s sound pack.
Speak the cue, provenance, and intent at point.
Speak the current cue-browser column title and value.
Activate the sound pack at point.
Audition a representative cue from the sound pack at point.
Guidedly edit safe manifest metadata for the discovered pack at point.
Display and speak sound-pack manager help.
Spoken manager for registered and dynamically discovered sound packs. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-sound-packs-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-list-sound-pack-cues ? emacsvox-aural-sound-packs-help P emacsvox-aural-sound-packs-audition a emacsvox-aural-sound-packs-activate e emacsvox-aural-sound-packs-edit-manifest h emacsvox-aural o emacsvox-aural-sound-packs-open-directory v emacsvox-aural-sound-packs-show-validation
Move to and speak the next sound pack.
Move right and speak the next sound-pack column.
Open the current sound pack’s directory in Dired.
Move to and speak the previous sound pack.
Move left and speak the previous sound-pack column.
Refresh the sound-pack manager, preserving PACK and the current column. (fn &optional PACK)
Display and speak validation for PACK-ID or the pack at point. (fn &optional PACK-ID)