Common interface identity, spoken tabulated-list navigation, refresh preservation, and dismissal feedback for the aural managers and editors.
Base mode for non-tabulated aural interfaces. In addition to any hooks its parent mode ‘special-mode’ might have run, this mode runs the hook ‘emacsvox-aural-interface-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- SPC scroll-up-command - negative-argument 0 .. 9 digit-argument < beginning-of-buffer > end-of-buffer ? describe-mode g revert-buffer h describe-mode q emacsvox-aural-quit DEL scroll-down-command S-SPC scroll-down-command
Dismiss the current aural interface and report its destination. When KILL is non-nil, kill the interface buffer as ‘quit-window’ would. (fn &optional KILL)
Base mode for spoken tabulated aural interfaces.
In addition to any hooks its parent mode ‘tabulated-list-mode’ might
have run, this mode runs the hook
‘emacsvox-aural-tabulated-mode-hook’, as the final or penultimate step
during initialization.
Key Binding
——————————————————————————-
TAB forward-button
C-n emacsvox-aural-ui-next-row
C-p emacsvox-aural-ui-previous-row
SPC emacsvox-aural-ui-speak-current-row
- negative-argument
. emacsvox-aural-ui-speak-current-cell
0 .. 9 digit-argument
< beginning-of-buffer
> end-of-buffer
? describe-mode
S tabulated-list-sort
g emacsvox-aural-ui-refresh
h describe-mode
n emacsvox-aural-ui-next-row
p emacsvox-aural-ui-previous-row
q emacsvox-aural-quit
{ tabulated-list-narrow-current-column
} tabulated-list-widen-current-column
DEL scroll-down-command
S-SPC scroll-down-command
M-<left> tabulated-list-previous-column
M-<right> tabulated-list-next-column
<backtab> backward-button
<down> emacsvox-aural-ui-next-row
<follow-link> mouse-face
<left> emacsvox-aural-ui-previous-column
<mouse-2> mouse-select-window
<right> emacsvox-aural-ui-next-column
<up> emacsvox-aural-ui-previous-row
C-M-i backward-button
Quit Help and restore its originating aural interface and position.
Return from Help to the exact aural interface that requested it. This is a minor mode. If called interactively, toggle the ‘Emacsvox-Aural-Ui-Help-Return mode’ mode. If the prefix argument is positive, enable the mode, and if it is zero or negative, disable the mode. If called from Lisp, toggle the mode if ARG is ‘toggle’. Enable the mode if ARG is nil, omitted, or is a positive number. Disable the mode if ARG is a negative number. To check whether the minor mode is enabled in the current buffer, evaluate the variable ‘emacsvox-aural-ui-help-return-mode’. The mode’s hook is called both when the mode is enabled and when it is disabled. (fn &optional ARG)
Move right and speak the next column.
Move to and speak the next row.
Move left and speak the previous column.
Move to and speak the previous row.
Refresh the current interface using its configured callback.
Hook run after entering or leaving ‘emacsvox-aural-ui-help-return-mode’. No problems result if this variable is not bound. ‘add-hook’ automatically binds it. (This is true for all hook variables.)
Default Value:
nil