Accessible management for inherited, data-safe ACSS voice palettes.
Open the spoken manager for voice PALETTE providers. (fn &optional PALETTE)
Copy the current voice to a new, independently routable voice.
Replace the effective voice at point using the guided definition editor.
Explain the effective voice at point.
Display and speak voice-palette preview help.
Spoken browser for effective voices in one palette. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-voice-palette-previews-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-voice-palette-previews-play ? emacsvox-aural-voice-palette-previews-help A emacsvox-aural-voice-palette-previews-play-all E emacsvox-aural-voice-palette-previews-edit N emacsvox-aural-voice-palette-previews-new P emacsvox-aural-voice-palette-previews-play S emacsvox-aural-voice-palette-previews-stop T emacsvox-aural-voice-palette-previews-set-text c emacsvox-aural-voice-palette-previews-copy e emacsvox-aural-voice-palette-previews-tune h emacsvox-aural o emacsvox-aural-voice-palette-previews-open-manager s emacsvox-aural-voice-palette-previews-stop t emacsvox-aural-voice-palette-previews-tune x emacsvox-aural-voice-palette-previews-explain
Create a new voice in the palette shown by the current preview.
Move to and speak the next effective voice.
Move right and speak the next voice column.
Return to the palette manager for the current preview palette.
Audition the effective voice at point with the comparison text.
Audition every effective voice using the same comparison text.
Move to and speak the previous effective voice.
Move left and speak the previous voice column.
Refresh palette voices, preserving VOICE and the current column. (fn &optional VOICE)
Set the comparison text used by this preview buffer.
Speak the complete palette voice row at point.
Speak the current preview column title and value.
Stop the current voice audition.
Open a transactional tuner for the effective voice at point.
Activate the voice palette at point as an override.
Copy the voice palette at point to a personal palette.
Create an empty personal voice palette.
Delete the personal voice palette at point when it is unreferenced.
Delete one direct entry from the personal palette at point.
Display and speak the effective voices in palette ID. (fn &optional ID)
Create or replace one direct voice entry in the personal palette at point.
Edit summary and parent of the personal palette at point.
Explain one effective voice and its adapter fallback. (fn &optional ID VOICE)
Clear the palette override and use the compatibility baseline.
Display and speak voice-palette manager help.
Spoken manager for inherited ACSS voice palettes. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-voice-palettes-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-voice-palettes-preview ? emacsvox-aural-voice-palettes-help B emacsvox-aural-voice-palettes-preview D emacsvox-aural-voice-palettes-delete-entry E emacsvox-aural-voice-palettes-edit-metadata N emacsvox-aural-voice-palettes-create P emacsvox-aural-voice-palettes-preview a emacsvox-aural-voice-palettes-activate c emacsvox-aural-voice-palettes-copy d emacsvox-aural-voice-palettes-delete e emacsvox-aural-voice-palettes-edit-entry f emacsvox-aural-voice-palettes-follow-baseline h emacsvox-aural v emacsvox-aural-voice-palettes-describe x emacsvox-aural-voice-palettes-explain
Move to and speak the next voice palette.
Move right and speak the next palette column.
Browse and audition all effective voices in palette ID or at point. (fn &optional ID)
Move to and speak the previous voice palette.
Move left and speak the previous palette column.
Refresh palettes while preserving ID and the current column. (fn &optional ID)
Speak the complete voice-palette row at point.
Speak the current palette column title and value.
Audition the unsaved working style after optional ANNOUNCEMENT. (fn &optional ANNOUNCEMENT)
Decrease the current numeric dimension and audition its new value.
Edit the current dimension and audition the new value.
Display and speak voice tuner help.
Increase the current numeric dimension and audition its new value.
Transactional spoken tuner for one personal-palette voice. In addition to any hooks its parent mode ‘emacsvox-aural-tabulated-mode’ might have run, this mode runs the hook ‘emacsvox-aural-voice-tuner-mode-hook’, as the final or penultimate step during initialization. Key Binding ——————————————————————————- RET emacsvox-aural-voice-tuner-edit + emacsvox-aural-voice-tuner-increase - emacsvox-aural-voice-tuner-decrease 0 .. 9 emacsvox-aural-voice-tuner-set-digit ? emacsvox-aural-voice-tuner-help P emacsvox-aural-voice-tuner-audition R emacsvox-aural-voice-tuner-restore d emacsvox-aural-voice-tuner-use-default e emacsvox-aural-voice-tuner-edit h emacsvox-aural q emacsvox-aural-voice-tuner-quit u emacsvox-aural-voice-tuner-undo w emacsvox-aural-voice-tuner-save <left> emacsvox-aural-voice-tuner-decrease <right> emacsvox-aural-voice-tuner-increase C-c C-c emacsvox-aural-voice-tuner-save C-c C-k emacsvox-aural-voice-tuner-quit
Move to and speak the next tunable dimension.
Move to and speak the previous tunable dimension.
Cancel tuning, asking before discarding unsaved changes.
Refresh the tuner while preserving DIMENSION and the current column. (fn &optional DIMENSION)
Restore and audition the style present when the tuner opened.
Atomically save the portable style and return to the voice preview.
Set the current numeric dimension from the typed digit and audition it.
Speak the complete tuner row at point.