2.67 emacsvox-chess ¶
The Emacs Chess package provides a rich environment for playing and
exploring Chess Games.
That package comes with a light-weight module that announces
moves.
This module aims to do much more, including:
- Navigate the board along various axes with audio-formatted output.
- Browse games via rich audio-formatted output.
- Speech-enable all interactive commands provided by the Chess
package.
- Enable various means of exploring the state of game, perhaps with
a view to being able to spot patterns from listening to the
output.
2.67.1 Navigating And Examining The Board ¶
The board can be navigated along the 8 compass directions.
Arrow keys move to the appropriate squares on the board.
/ and \ move down the diagonals.
[ and ] move up the respective diagonals.
- Move North:
emacsvox-chess-north bound to up.
- Move South:
emacsvox-chess-south bound to
down.
- Move West:
emacsvox-chess-west bound to left.
- Move East:
emacsvox-chess-east bound to right.
You can also move along the diagonals:
- Move Northwest:
emacsvox-chess-northwest bound to
[.
- Move Northeast:
emacsvox-chess-northeast bound to ].
- Move Southwest:
emacsvox-chess-southwest bound to
/.
- Move Southeast:
emacsvox-chess-southeast bound to
\.
You can also jump to a given board position by:
- Jump:
emacsvox-chess-jump bound to j.
- Target of last move:
emacsvox-chess-goto-target bound to t.
- Look:
emacsvox-chess-speak-that-square bound to
l.
- Review current square: ;.
- Review Board:
emacsvox-chess-speak-board bound to
z. Useful in end-state.
- Locate pieces:
emacsvox-chess-speak-piece-squares
bound to s. Specify piece as a single char — w speaks
all white pieces, l speaks all black pieces, use SAN notation
char for a specific piece. Use a to hear entire board, this
last is most useful when the game is an end-state.
- Discover who targets a square:
emacsvox-chess-speak-who-targets bound to w. Argument
piece is similar to the previously listed command.
You can obtain views of the board along the rows and diagonals, as
well as a knight’s perspective :
- Viewers: v followed by the directional navigation keys
speaks the squares in that direction from the current
square. vn speaks the squares from a knight’s perspective,
i.e. the squares the Knight would see from the current
position. similarly, vk speaks the non-empty squares seen by the King
from the current position.
v followed by a rank-or-file char speaks that complete rank
or file.
2.67.2 Examining Games ¶
Package Chess allows one to browse through a game using
, and . — chess-display-move-backward and
chess-display-move-forward. Emacsvox speech-enables these
commands to speak the move that led to the currently displayed
state of the game. Finally, m speaks the current move
being displayed.
2.67.3 Emacsvox-Chess Commands ¶
2.67.3.1 emacsvox-chess-east ¶
- Command: emacsvox-chess-east ¶
-
2.67.3.2 emacsvox-chess-goto-target ¶
- Command: emacsvox-chess-goto-target ¶
-
2.67.3.3 emacsvox-chess-jump ¶
- Command: emacsvox-chess-jump (coord) ¶
-
2.67.3.4 emacsvox-chess-look-east ¶
- Command: emacsvox-chess-look-east ¶
-
2.67.3.5 emacsvox-chess-look-king ¶
- Command: emacsvox-chess-look-king ¶
-
2.67.3.6 emacsvox-chess-look-knight ¶
- Command: emacsvox-chess-look-knight ¶
-
2.67.3.7 emacsvox-chess-look-north ¶
- Command: emacsvox-chess-look-north ¶
-
2.67.3.8 emacsvox-chess-look-northeast ¶
- Command: emacsvox-chess-look-northeast ¶
-
2.67.3.9 emacsvox-chess-look-northwest ¶
- Command: emacsvox-chess-look-northwest ¶
-
2.67.3.10 emacsvox-chess-look-south ¶
- Command: emacsvox-chess-look-south ¶
-
2.67.3.11 emacsvox-chess-look-southeast ¶
- Command: emacsvox-chess-look-southeast ¶
-
2.67.3.12 emacsvox-chess-look-southwest ¶
- Command: emacsvox-chess-look-southwest ¶
-
2.67.3.13 emacsvox-chess-look-west ¶
- Command: emacsvox-chess-look-west ¶
-
2.67.3.14 emacsvox-chess-north ¶
- Command: emacsvox-chess-north ¶
-
2.67.3.15 emacsvox-chess-northeast ¶
- Command: emacsvox-chess-northeast ¶
-
2.67.3.16 emacsvox-chess-northwest ¶
- Command: emacsvox-chess-northwest ¶
-
2.67.3.17 emacsvox-chess-south ¶
- Command: emacsvox-chess-south ¶
-
2.67.3.18 emacsvox-chess-southeast ¶
- Command: emacsvox-chess-southeast ¶
-
2.67.3.19 emacsvox-chess-southwest ¶
- Command: emacsvox-chess-southwest ¶
-
2.67.3.20 emacsvox-chess-speak-board ¶
- Command: emacsvox-chess-speak-board ¶
-
2.67.3.21 emacsvox-chess-speak-piece-squares ¶
- Command: emacsvox-chess-speak-piece-squares (piece) ¶
-
2.67.3.22 emacsvox-chess-speak-that-square ¶
- Command: emacsvox-chess-speak-that-square (coord) ¶
-
2.67.3.23 emacsvox-chess-speak-this-move ¶
- Command: emacsvox-chess-speak-this-move ¶
-
2.67.3.24 emacsvox-chess-speak-this-square ¶
- Command: emacsvox-chess-speak-this-square ¶
-
2.67.3.25 emacsvox-chess-speak-who-targets ¶
- Command: emacsvox-chess-speak-who-targets (piece) ¶
-
2.67.3.26 emacsvox-chess-view-rank-or-file ¶
- Command: emacsvox-chess-view-rank-or-file ¶
-
2.67.3.27 emacsvox-chess-west ¶
- Command: emacsvox-chess-west ¶
-