2.135 emacsvox-google ¶
There are a number of search tools that can be implemented on
the Google search page — in a JS-powered browser, these
show up as the Google tool-belt.
This module implements a minor mode for use in Google result
pages that enables these tools via single keyboard commands.
Originally all options were available as tbs=p:v
Now, some specialized searches, e.g. blog search are tbm=
2.135.1 Emacsvox-Google Commands ¶
2.135.1.2 emacsvox-google-knowledge-search ¶
- Command: emacsvox-google-knowledge-search (query &optional limit) ¶
-
2.135.1.3 emacsvox-google-on-this-site ¶
- Command: emacsvox-google-on-this-site ¶
-
2.135.1.4 emacsvox-google-open-link ¶
- Command: emacsvox-google-open-link ¶
-
2.135.1.5 emacsvox-google-search-after ¶
- Command: emacsvox-google-search-after ¶
-
2.135.1.6 emacsvox-google-search-before ¶
- Command: emacsvox-google-search-before ¶
-
2.135.1.8 emacsvox-google-sign-in ¶
- Command: emacsvox-google-sign-in ¶
-
2.135.1.9 emacsvox-google-sign-out ¶
- Command: emacsvox-google-sign-out ¶
-
2.135.1.10 emacsvox-google-similar-to-this-page ¶
- Command: emacsvox-google-similar-to-this-page (url) ¶
-
2.135.1.12 emacsvox-google-tts-line ¶
- Command: emacsvox-google-tts-line (&optional lang) ¶
- C-. g l ¶
- C-x @ s g l ¶
2.135.1.13 emacsvox-google-tts-next-line ¶
- Command: emacsvox-google-tts-next-line ¶
- C-. g n ¶
- C-x @ s g n ¶
2.135.1.14 emacsvox-google-tts-previous-line ¶
- Command: emacsvox-google-tts-previous-line ¶
- C-. g p ¶
- C-x @ s g p ¶
2.135.1.15 emacsvox-google-tts-region ¶
- Command: emacsvox-google-tts-region (start end &optional ask-lang) ¶
- C-. g r ¶
- C-x @ s g r ¶
2.135.1.16 emacsvox-google-tts-speak ¶
- Command: emacsvox-google-tts-speak (text &optional lang) ¶
- C-. g s ¶
- C-x @ s g s ¶
2.135.1.17 emacsvox-google-what-is-my-ip ¶
- Command: emacsvox-google-what-is-my-ip ¶
-
2.135.1.18 emacsvox-google-who-links-to-this-page ¶
- Command: emacsvox-google-who-links-to-this-page ¶
-
2.135.1.19 emacsvox-google-yt-feed ¶
- Command: emacsvox-google-yt-feed (url) ¶
- C-' y ¶
2.135.2 emacsvox-google Options ¶
- Variable: User Option emacsvox-google-kg-key ¶
API Key for Google Knowledge Graph.
Default Value:
nil