This module speech enables ispell. Implementation note: This is hard because of how ispell.el is written Namely, all of the work is done by one huge hairy function. This makes advising it hard. The ispell commands work well with Emacsvox as long as the list of correction choices are few. For interactively moving through corrections, install package flyspell-correct from MELPA (package-install "flyspell-correct") Then use M-x flyspell-mode. Package flyspell is speech-enabled by Emacsvox module emacsvox-flyspell. That module uses standard completion by default, so Vertico or another active completion frontend presents correction choices. IDO, Popup, and Helm remain available as explicit alternatives.