Speech-enable org — Org allows you to keep organized notes and todo lists. Homepage: http://www.astro.uva.nl/~dominik/Tools/org/ or http://orgmode.org/
Loop through and play list of Amarks from org buffer. Hit C-g to break out of the loop. Press ‘y’ to play to next amark.
Capture hyperlink to current context. To use this command, first do ‘customize-variable’ ‘org-capture-template’ and assign letter ‘h’ to a template that creates the hyperlink on capture. Optional interactive prefix arg just opens the file (fn &optional OPEN)
Provide an input buffer in a specified mode. (fn MODE)
Speak the current Org item through one semantic presentation.
Speak both headers and the current Org table cell.
Speak the current Org table column header.
Speak the column header and current Org table cell.
Speak the current Org table coordinates.
Speak the current Org table cell.
Emacsvox org hotlist location.
Default Value:
"~/.org/hotlist.org"
The function to call after moving in a table
Default Value:
emacsvox-org-table-speak-current-element