Speak the question, revealed answer, rating result, and session lifecycle of Org-srs. Confirmation is command based by default so screen-reader navigation does not accidentally reveal an answer.
Rate the current Org-srs item as again.
Rate the current Org-srs item as easy.
Rate the current Org-srs item as good.
Rate the current Org-srs item as hard.
Provide accessible keys while an Org-srs item is being reviewed. This is a minor mode. If called interactively, toggle the ‘Emacsvox-Org-Srs-Review mode’ mode. If the prefix argument is positive, enable the mode, and if it is zero or negative, disable the mode. If called from Lisp, toggle the mode if ARG is ‘toggle’. Enable the mode if ARG is nil, omitted, or is a positive number. Disable the mode if ARG is a negative number. To check whether the minor mode is enabled in the current buffer, evaluate the variable ‘emacsvox-org-srs-review-mode’. The mode’s hook is called both when the mode is enabled and when it is disabled. (fn &optional ARG)
Whether the first question announces the number of pending items.
Default Value:
t
Hook run after entering or leaving ‘emacsvox-org-srs-review-mode’. No problems result if this variable is not bound. ‘add-hook’ automatically binds it. (This is true for all hook variables.)
Default Value:
nil
Use an explicit command to reveal each Org-srs answer. This prevents ordinary screen-reader navigation keys from being consumed by ‘read-key’ and revealing the answer. During a review, use ‘C-c C-c’ to reveal the answer.
Default Value:
t