This module implements user customizable pronunciation dictionaries for emacsvox. Custom pronunciations can be defined per file, per directory and/or per major mode. Emacsvox maintains a persistent user dictionary upon request and loads these in new emacsvox sessions. This module implements the user interface to the custom dictionary as well as providing the internal API used by the rest of emacsvox in using the dictionary.
The persistent dictionary is a hash table where the hash keys are filenames, directory names, or major-mode names. The hash values are association lists defining the dictionary. Users of this module can retrieve a dictionary made up of all applicable association lists for a given file.
Clear all current pronunciation dictionaries.
Interactively define entries in the pronunciation dictionaries. Default term to define is delimited by region. First loads any persistent dictionaries if not already loaded.
Interactively define template entries in the pronunciation dictionaries. Default term to define is delimited by region. First loads any persistent dictionaries if not already loaded.
Prompt for and launch a pronunciation editor on the specified pronunciation dictionary key. (fn KEY)
Load pronunciation dictionaries. Optional argument FILENAME specifies the dictionary file, Default is emacsvox-pronounce-dictionaries-file. (fn &optional FILENAME)
Merge dic ‘from’ into dict ‘into’ (fn FROM INTO)
Refresh pronunciation table for current buffer.
Saves pronunciation dictionaries.
File that holds emacsvox pronunciations.
Default Value:
"~/.emacsvox/.dictionary"
Smileys
Default Value:
((":-)" . " smile ")
(";)" . " half-wink ")
(":)" . " grin ")
(":-(" . " frown ")
(":(" . " sigh ")
(":-I" . " shrug ")
(":->" . " sarcastic smile ")
(">:->" . " devillish smile ")
(">;->" . " lewd smile ")
(";-)" . " wink "))
Namespace URIs.
Default Value:
(("http://www.w3.org/2005/Atom" . " atom ")
("http://www.w3.org/1999/02/22-rdf-syntax-ns#" . "RDF Syntax")
("http://www.w3.org/2002/06/xhtml2" . " xhtml2 ")
("http://www.w3.org/2003/XInclude" . "XInclude")
("http://www.w3.org/1999/XSL/Transform" . " XSLT ")
("http://www.w3.org/2002/xforms" . " XForms ")
("http://www.w3.org/2001/xml-events" . " XEvents ")
("http://www.w3.org/2001/vxml" . " vxml ")
("http://www.w3.org/2001/XMLSchema-instance" . " XSI ")
("http://www.w3.org/2001/XMLSchema" . " XSD ")
("http://www.w3.org/1999/xhtml" . " xhtml ")
("http://purl.org/dc/elements/1.1/" . "DC")
("http://search.yahoo.com/mrss/" . "media"))