This module advises speedbar.el for use with Emacs. The latest speedbar can be obtained from ftp://ftp.ultranet.com/pub/zappo/ This module ensures that speedbar works smoothly outside a windowing system in addition to speech enabling all interactive commands. Emacsvox also adds an Emacsvox environment specific entry point to speedbar –emacsvox-speedbar-goto-speedbar– and binds this