Next: emacsvox-vertico, Previous: emacsvox-vdiff, Up: Emacsvox Commands And Options [Index]
Read the canonical release identifier from the repository-level VERSION file. Reading it when this module loads keeps source and byte-code users on the same value without generating a second version source.