Next: emacsvox-widget, Previous: emacsvox-webspace, Up: Emacsvox Commands And Options [Index]
Which-Key displays available keybindings in a popup after pressing a prefix key. This module speech-enables Which-Key to provide auditory feedback for available bindings, supporting navigation through pages and speaking the current binding options.
Speak the current or last which-key popup content.
Toggle automatic speaking of which-key popups.